<?php

/*
 * Serbian language
 */

$lang['text_rest_invalid_api_key'] = 'Nepravilan API klju&#269; %s'; // %s je REST API ključ
$lang['text_rest_invalid_credentials'] = 'Neodgovaraju&#263;i korisni&#269;ki ulazni podaci';
$lang['text_rest_ip_denied'] = 'IP odbijen';
$lang['text_rest_ip_unauthorized'] = 'IP neautorizovan';
$lang['text_rest_unauthorized'] = 'Neautorizovano';
$lang['text_rest_ajax_only'] = 'Jedino AJAX zahtevi su dozvoljeni';
$lang['text_rest_api_key_unauthorized'] = 'Ovaj API klju&#269; nema ovla&#353;&#263;enje za zahtevani kontroler';
$lang['text_rest_api_key_permissions'] = 'Ovaj API klju&#269; nema dozvoljen stepen ovla&#353;&#263;enja';
$lang['text_rest_api_key_time_limit'] = 'Ovaj API klju&#269; je prekora&#269;io vremenski limit za dati metod';
$lang['text_rest_ip_address_time_limit'] = 'Ova IP adresa je prekora&#269;ila vremenski limit za dati metod';
$lang['text_rest_unknown_method'] = 'Nepoznat metod';
$lang['text_rest_unsupported'] = 'Nepodr&#382;an protokol';
