<?php

/*
 * Brazilian portuguese language
 */

$lang['text_rest_invalid_api_key'] = 'Chave da API %s inválida'; // %s is the REST API key
$lang['text_rest_invalid_credentials'] = 'Credenciais inválidas';
$lang['text_rest_ip_denied'] = 'IP proibido';
$lang['text_rest_ip_unauthorized'] = 'IP não autorizado';
$lang['text_rest_unauthorized'] = 'Não autorizado';
$lang['text_rest_ajax_only'] = 'Apenas chamadas AJAX são permitidas';
$lang['text_rest_api_key_unauthorized'] = 'Esta chave da API não tem acesso ao controller solicitado';
$lang['text_rest_api_key_permissions'] = 'Esta chave da API não tem permissões suficientes';
$lang['text_rest_api_key_time_limit'] = 'Esta chave da API já atingiu o tempo limite para este método';
$lang['text_rest_ip_address_time_limit'] = 'Este Endereço IP atingiu o limite de tempo para este método';
$lang['text_rest_unknown_method'] = 'Método desconhecido';
$lang['text_rest_unsupported'] = 'Sem suporte para este protocolo';
