<?php

$lang['{0} taken into account.'] = '{0} pris en compte.';
$lang['{0} taken into account. To opt-in again, send "{1}".'] = '{0} pris en compte. Pour recevoir à nouveau, répondre "{1}".';
$lang['{0} taken into account. To opt-out, send "{1}".'] = '{0} pris en compte. Pour ne plus recevoir, répondre "{1}".';
$lang['Request not valid ({0}). Send "{1} or {2} <type>". Possible values for <type> are: {3}. For example "{4}".'] = 'Demande non valide ({0}). Répondre "{1} ou {2} <type>". Les valeurs possibles pour <type> sont: {3}. Par exemple "{4}".';
$lang['Request not valid ({0}). Send "{1} <type>". Possible values for <type> are: {2}. For example "{3}".'] = 'Demande non valide ({0}). Répondre "{1} <type>". Les valeurs possibles pour <type> sont: {2}. Par exemple "{3}".';
$lang['Request not valid ({0}). Send "{1}" or "{2}". For example "{3}".'] = 'Demande non valide ({0}). Répondre "{1}" ou "{2}". Par exemple "{3}".';
$lang['Request not valid ({0}). Send "{1}".'] = 'Demande non valide ({0}). Répondre "{1}".';
$lang['Stop Manager records'] = 'Enregistrements de Stop Manager';
$lang['Add STOP record'] = 'Ajouter une entrée STOP';
$lang['Type'] = 'Type';
$lang['Original opt-out SMS'] = 'Message STOP d\'origine';
