<?php

/*
 * Spanish language
 */

$lang['text_rest_invalid_api_key'] = 'API key %s No válida'; // %s is the REST API key
$lang['text_rest_invalid_credentials'] = 'Credenciales Inválidas';
$lang['text_rest_ip_denied'] = 'IP denegada';
$lang['text_rest_ip_unauthorized'] = 'IP no autorizada';
$lang['text_rest_unauthorized'] = 'Acceso no autorizado';
$lang['text_rest_ajax_only'] = 'Sólo peticiones ajax permitidas';
$lang['text_rest_api_key_unauthorized'] = 'Esta clave de API no tiene acceso al controlador solicitado';
$lang['text_rest_api_key_permissions'] = 'Esta clave de API no tiene suficientes permisos';
$lang['text_rest_api_key_time_limit'] = 'Esta clave de API ha alcanzado el límite de tiempo para este método';
$lang['text_rest_ip_address_time_limit'] = 'Esta dirección IP ha alcanzado el límite de tiempo para este método'; //todo translate
$lang['text_rest_unknown_method'] = 'Método desconocido';
$lang['text_rest_unsupported'] = 'Protocolo no soportado';
