<?php

/*
 * Traditional Chinese language
 */

$lang['text_rest_invalid_api_key'] = '無效的 API 金鑰 %s'; // %s is the REST API key
$lang['text_rest_invalid_credentials'] = '無效的憑證';
$lang['text_rest_ip_denied'] = 'IP 位置被拒絕';
$lang['text_rest_ip_unauthorized'] = 'IP 位置未認證';
$lang['text_rest_unauthorized'] = '未認證';
$lang['text_rest_ajax_only'] = '只有 AJAX 類型請求被允許';
$lang['text_rest_api_key_unauthorized'] = '這個 API 金鑰沒有辦法存取指定的 controller';
$lang['text_rest_api_key_permissions'] = '這個 API 金鑰沒有具備足夠權限';
$lang['text_rest_api_key_time_limit'] = '這個 API 金鑰已經超過有效期限';
$lang['text_rest_ip_address_time_limit'] = '這個 IP 位置的流量已經超過上限';
$lang['text_rest_unknown_method'] = '未知的方法';
$lang['text_rest_unsupported'] = '不支援的通訊協定';
