<?php
/**
 * System messages translation for CodeIgniter(tm)
 *
 * @author	CodeIgniter community
 * @copyright	Copyright (c) 2014-2019, British Columbia Institute of Technology (https://bcit.ca/)
 * @license	http://opensource.org/licenses/MIT	MIT License
 * @link	https://codeigniter.com
 */
defined('BASEPATH') OR exit('No direct script access allowed');

$lang['date_year'] = 'Rok';
$lang['date_years'] = 'Roky';
$lang['date_month'] = 'Měsíc';
$lang['date_months'] = 'Měsíce';
$lang['date_week'] = 'Týden';
$lang['date_weeks'] = 'Týdny';
$lang['date_day'] = 'Den';
$lang['date_days'] = 'Dny';
$lang['date_hour'] = 'Hodina';
$lang['date_hours'] = 'Hodiny';
$lang['date_minute'] = 'Minuta';
$lang['date_minutes'] = 'Minuty';
$lang['date_second'] = 'Sekunda';
$lang['date_seconds'] = 'Sekundy';

$lang['UM12'] = '(UTC -12:00) Bakerův/Howlanův ostrov';
$lang['UM11'] = '(UTC -11:00) Niue';
$lang['UM10'] = '(UTC -10:00) Hawajsko-Aleutianský Standardní čas, Cookovy ostrovy, Tahiti';
$lang['UM95'] = '(UTC -9:30) Markézy';
$lang['UM9'] = '(UTC -9:00) Alijašský Standardní čas, Gambierovy ostrovy';
$lang['UM8'] = '(UTC -8:00) Pacifický Standardní čas, Clippertonovy ostrovy';
$lang['UM7'] = '(UTC -7:00) Horský Standardní čas';
$lang['UM6'] = '(UTC -6:00) Centrální Standardní čas';
$lang['UM5'] = '(UTC -5:00) Východní Standardní čas, Západní Karibský Standardní čas';
$lang['UM45'] = '(UTC -4:30) Venezuelský Standardní čas';
$lang['UM4'] = '(UTC -4:00) Atlantický Standardní čas, Východní Karibský Standardní čas';
$lang['UM35'] = '(UTC -3:30) Novofundlandský Standardní čas';
$lang['UM3'] = '(UTC -3:00) Argentina, Brazilie, Francouzská Guiana, Uruguay';
$lang['UM2'] = '(UTC -2:00) Jižní Georgie a Jižní Sandwichovy ostrovy';
$lang['UM1'] = '(UTC -1:00) Azory, Ostrovy Cape Verde';
$lang['UTC'] = '(UTC) Greenwichský poledník, Západoevropský Čas';
$lang['UP1'] = '(UTC +1:00) Středoevropský Čas, Západoafrický Čas';
$lang['UP2'] = '(UTC +2:00) Středoafrický Čas, Východoevropský Čas, Kaliningradský Čas';
$lang['UP3'] = '(UTC +3:00) Moskva, Východoafrický Čas, Arabský Standardní čas';
$lang['UP35'] = '(UTC +3:30) Íránský Standardní čas';
$lang['UP4'] = '(UTC +4:00) Azerbaidžánský Standardní čas, Samarský čas';
$lang['UP45'] = '(UTC +4:30) Afghánistán';
$lang['UP5'] = '(UTC +5:00) Pákistánský Standardní čas, Yekaterinburgský Čas';
$lang['UP55'] = '(UTC +5:30) Indický Standardní čas, Sri Lanka';
$lang['UP575'] = '(UTC +5:45) Nepál';
$lang['UP6'] = '(UTC +6:00) Bangladéšský Standardní čas, Bhutan, Omsk';
$lang['UP65'] = '(UTC +6:30) Kokosové Ostrovy, Myanmar';
$lang['UP7'] = '(UTC +7:00) Krasnoyarský Čas, Cambodža, Laos, Thajsko, Vietnam';
$lang['UP8'] = '(UTC +8:00) Západoaustralský Standardní čas, Pekingský Čas, Irkutsk';
$lang['UP875'] = '(UTC +8:45) Středoaustralský Standardní čas';
$lang['UP9'] = '(UTC +9:00) Japonský Standardní čas, Korejský Standardní čas, Yakutský Čas';
$lang['UP95'] = '(UTC +9:30) Australian Central Standardní čas';
$lang['UP10'] = '(UTC +10:00) Východoaustralský Standardní čas, Vladivostok';
$lang['UP105'] = '(UTC +10:30) Ostrov lorda Howa';
$lang['UP11'] = '(UTC +11:00) Sredněkolymský Čas, Solomonovy Ostrovy, Vanuatu';
$lang['UP115'] = '(UTC +11:30) Norfol (Ostrov)';
$lang['UP12'] = '(UTC +12:00) Fiji, Gilbertovy Ostrovy, Kamčatský Čas, Novozélandský Standardní čas';
$lang['UP1275'] = '(UTC +12:45) Chathamovy ostrovy';
$lang['UP13'] = '(UTC +13:00) Samoa Časová Zóna, Fénixovy Ostrovy, Tonga';
$lang['UP14'] = '(UTC +14:00) Liniové ostrovy';
