<?php
// French Translation
// Author: Manue Caliot , Martin Deschamps SEAS>

// Global
$lang['Dashboard'] = 'Tableau de bord';
$lang['Folders'] = 'Dossiers';
$lang['My folders'] = 'Mes dossiers';

$lang['Compose'] = 'Ecrire';
$lang['Inbox'] = 'Boite de réception';
$lang['Outbox'] = "Boite d'envoi";
$lang['Sent items'] = 'Messages envoyés';
$lang['Sending error'] = 'Envois en erreur';
$lang['Trash'] = 'Corbeille';
$lang['Spam'] = 'Spam';
$lang['Add'] = 'Ajouter';
$lang['Action'] = 'Action';

$lang['Phonebook'] = 'Répertoire';
$lang['Settings'] = 'Paramètres';
$lang['Filters'] = 'Filtres';
$lang['About {0}'] = 'A propos de {0}';
$lang['Logout'] = 'Déconnexion';

// Dashboard
$lang['Statistics'] = 'Statistiques';
$lang['System information'] = 'Informations du système';
$lang['Alerts'] = 'Alertes';
$lang['Operating system'] = "Système d'exploitation";
$lang['Gammu version'] = 'Gammu Version';
$lang['Gammu DB schema'] = 'Gammu DB Schema';
$lang['Modem IMEI'] = 'Modem IMEI';

// Phonebook
$lang['Contact'] = 'Contact';
$lang['All contacts'] = 'Tous les contacts';
$lang['Send to all contacts'] = 'Envoyer à tous les contacts';
$lang['Add to group'] = 'Ajouter au groupe';
$lang['Delete from group'] = 'Supprimer du groupe';
$lang['Select add contact method'] = "Sélectionner la méthode d'ajout de contact";
$lang['Manual input'] = 'Utiliser le formulaire de contact';
$lang['Manually add contact using contact form'] = 'Ajouter manuellement un contact';
$lang['From CSV file'] = 'Importer un fichier CSV';
$lang['Import contact from CSV format file'] = "Importer des contacts à partir d'un fichier CSV";
$lang['CSV file'] = 'Fichier CSV';
$lang['The CSV file must be in valid format'] = 'Le fichier CSV doit être au bon format';
$lang['Are you sure you want to delete {0} contact(s)?'] = 'Êtes-vous sûr(s) de vouloir supprimer {0} contacts ?';
$lang['valid example'] = 'Exemple valide';

// Message
$lang['Message'] = 'Message';
$lang['Send to'] = 'Destinataire';
$lang['Reply'] = 'Répondre';
$lang['Forward'] = 'Transférer';
$lang['Forward to'] = 'Faire suivre';
$lang['Move to'] = 'Déplacer';
$lang['Select folder'] = 'Sélectionner le dossier';
$lang['Delete'] = 'Supprimer';
$lang['Click to delete this folder'] = 'Cliquer pour supprimer ce dossier';
$lang['Recover'] = 'Récupérer';

$lang['Send date'] = "Date d'envoi";
$lang['Now'] = 'Maintenant';
$lang['At date and time'] = 'A la date et heure';
$lang['After a delay'] = 'Après un délai';

$lang['Input manually'] = 'Saisie manuelle';

$lang['Add folder'] = 'Ajouter dossier';
$lang['Folder name'] = 'Nom de dossier';
$lang['Cancel'] = 'Annuler';
$lang['Save'] = 'Enregistrer';
$lang['Rename'] = 'Renommer';
$lang['Rename folder'] = 'Renommer le dossier';
$lang['Click to rename this folder'] = 'Cliquer pour renommer ce dossier';

$lang['This folder and all messages in it will be deleted permanently and cannot be recovered. Are you sure?'] = "Ce dossier et tous les messages qu'il contient sera supprimé définitivement et ne pourra être restauré. Êtes-vous sûr(e) ?";

$lang['There is no message in {0}.'] = "Il n'y a aucun message dans {0}.";
$lang['There is no message in this folder.'] = "Il n'y a aucun message dans ce dossier.";

$lang['Delete all'] = 'Tout supprimer';
$lang['Are you sure? This will affect all conversations.'] = "Êtes-vous sûr(e) ? Ceci s'appliquera à toutes les conversations.";

$lang['Select all'] = 'Tout sélectionner';
$lang['Deselect all'] = 'Tout désélectionner';
$lang['Refresh'] = 'Actualiser';

$lang['Report spam'] = 'Signaler comme spam';
$lang['Not spam'] = 'Pas du spam';


$lang['SMSC'] = 'SMSC';
$lang['Part'] = 'Partie';
$lang['Validity'] = 'Validité';
$lang['default'] = 'par défaut';
$lang['5 minutes'] = '5 minutes';
$lang['10 minutes'] = '10 minutes';
$lang['30 minutes'] = '30 minutes';
$lang['1 hour'] = '1 heure';
$lang['2 hours'] = '2 heures';
$lang['4 hours'] = '4 heures';
$lang['12 hours'] = '12 heures';
$lang['1 day'] = '1 jour';
$lang['2 days'] = '2 jours';
$lang['5 days'] = '5 jours';
$lang['1 week'] = '1 semaine';
$lang['2 weeks'] = '2 semaines';
$lang['4 weeks'] = '4 semaines';
$lang['maximum'] = 'maximum';

$lang['SMS type'] = 'Type de sms';
$lang['Normal'] = 'Normal';
$lang['Flash'] = 'Flash';
$lang['WAP push link'] = 'Insérer un lien';
$lang['URL'] = 'URL';

$lang['Ads is active'] = 'Ads est activé';
$lang['Check DND'] = 'Vérifier DND';
$lang['Insert'] = 'Insérer';

$lang['Canned responses'] = 'Modèles';
$lang['There are no canned responses. Continue to save your present message as canned response.'] = "Il n'y a pas de modèle. Continuez pour enregistrer cette réponse et la conserver comme modèle.";
$lang['Choose response'] = 'Choisissez une réponse';
$lang['Saving...'] = 'Sauvegarde...';
$lang['Are you sure?'] = 'Etes-vous sûr(e) ?';

// Others
$lang['Amount'] = 'Quantité';
$lang['times']['repetition'] = 'fois';
$lang['Hour(s)'] = 'Heure(s)';
$lang['Minutes'] = 'Minutes';
$lang['No result.'] = 'Pas de résultat.';
$lang['See conversation'] = 'Voir la conversation';

$lang['Search'] = 'Rechercher';
$lang['Advanced search'] = 'Recherche avancée';
$lang['Folder'] = 'Dossier';
$lang['All'] = 'Tous';
$lang['Date from'] = 'Date à partir de';
$lang['Date to'] = "Jusqu'à la date";
$lang['Status'] = 'Statut';
$lang['Paging'] = 'Résultats par page';
$lang['{0} per page'] = '{0} par page';

$lang['Resend'] = 'Renvoyer';
$lang['Public contacts'] = 'Contacts publics';
$lang['Set as public contact'] = 'Définir comme contact public';
$lang['My contacts'] = 'Mes contacts';
$lang['Public groups'] = 'Groupes publics';
$lang['Set as public group'] = 'Définir comme un groupe public';
$lang['My groups'] = 'Mes groupes';
$lang['Incoming SMS'] = 'SMS reçus';
$lang['Outgoing SMS'] = 'SMS envoyés';
$lang['Delete all messages now'] = 'Supprimer tous les messages';
$lang['Delete contact(s) confirmation'] = 'Confirmation de la suppression du contact';
$lang['Should be a valid URL'] = "L'URL doit étre valide";
$lang['Import from file'] = 'Importer à partir du fichier';

// Messages controller
$lang['Outgoing SMS disabled.'] = 'SMS sortants désactivés.';
$lang['A number was found in DND Resitry. SMS sending was skipped for it.'] = "Un numéro a été trouvé dans le registre DND. L'envoi est annulé pour celui-ci.";
$lang['Message delivered successfully to user inbox.'] = "Message placé avec succès dans la boîte de réception de l'utilisateur.";
$lang['Copy of the message was placed in the outbox and is ready for delivery.'] = "Message placé dans la boite d'envoi et prêt à être envoyé.";
$lang['No number found. SMS not sent.'] = 'Pas de numéro trouvé. SMS non envoyé.';
$lang['Only administrators can permanently delete messages.'] = 'Seuls les administrateurs peuvent supprimer des messages de façon définitive.';

// Setting
$lang['Current password'] = 'Mot de passe actuel';
$lang['Forgot your password?'] = 'Mot de passe oublié ?';
$lang['New password'] = 'Nouveau mot de passe';
$lang['Must be at least 6 characters long'] = 'Doit comprendre au minimum 6 caractères';

$lang['Enter your new password'] = 'Entrer votre nouveau mot de passe';

$lang['Administrator'] = 'Administrateur';
$lang['User']['credentials'] = 'Utilisateur';

$lang['Create a new filter'] = 'Créer un nouveau filtre';
$lang['Has the words'] = 'Contient les mots';

// SMS Content/Member
$lang['Member'] = 'Membre';
$lang['Total member'] = 'Total des membres';
$lang['There is no registered member yet'] = "Il n'y a pas encore de membre inscrit";

// tni contribution
$lang['Add contact'] = 'Ajouter un contact';
$lang['Send message'] = 'Envoyer';
$lang['Send and repeat'] = 'Envoyer et répéter';
$lang['Sending'] = 'Envoi en cours';
$lang['Insert name from contact list'] = 'Insérer un nom depuis la liste de contact';
$lang['Delete group(s) confirmation'] = 'Confirmation de la suppression de groupe(s)';
$lang['Delete group(s)?
All their contacts will also be deleted.'] = 'Supprimer le(s) groupe(s) ?
Tous leurs contacts seront également supprimés.';
$lang['Create group'] = 'Créer un groupe';
$lang['Group name'] = 'Nom du groupe';
$lang['Groups'] = 'Groupes';
$lang['Manage groups'] = 'Gérer les groupes';
$lang['Manage group'] = 'Gérer un groupe';
$lang['Manage contact'] = 'Gérer les contacts';
$lang['Type group name'] = 'Entrer le nom du groupe';
$lang['No item selected.'] = 'Aucun élément sélectionné.';
$lang['No contact selected.'] = 'Aucun contact sélectionné.';
$lang['Compose SMS'] = 'Ecrire un sms';
$lang['Contacts'] = 'Contacts';
$lang['Back to {0}'] = 'Retour à {0}';
$lang['Show details'] = 'Afficher les détails';
$lang['Hide details'] = 'Masquer les détails';
$lang['Search contacts'] = 'Rechercher contact';
$lang['Search messages'] = 'Rechercher message';
$lang['Edit'] = 'Editer';
$lang['All form fields are required.'] = 'Tous les champs sont obligatoires.';
$lang['Name'] = 'Nom';
$lang['Telephone number'] = 'Numéro de téléphone';
$lang['Email ID'] = 'Email';
$lang['Enable email forwarding'] = "Activer le transfert d'Email";
$lang['{0} remaining'] = '{0} restant';
$lang['{0} ago'] = 'Il y a {0}';
$lang['Edit contact'] = 'Modifier contact';
$lang['Contact not found'] = 'Contact non trouvé';
$lang['No contacts in the database.'] = 'Le contact est vide';
$lang['Add user'] = 'Ajouter un utilisateur';
$lang['Edit user'] = 'Modifier un utilisateur';
$lang['User']['default'] = 'Utilisateur';
$lang['Users'] = 'Utilisateurs';
$lang['This deletes the selected users and all their messages and contacts.'] = "Supprimer l'utilisateur ?
Cela inclut tous les enregistrements de cet utilisateur (messages et contacts).";
$lang['User not found'] = 'Utilisateur introuvable';
$lang['No users in the database.'] = 'Les utilisateurs sont vides';
$lang['Username'] = "Nom d'utilisateur";
$lang['Password'] = 'Mot de passe';
$lang['Search user'] = 'Chercher un utilisateur';
$lang['Confirm password'] = 'Confirmer le mot de passe';
$lang['Phone number'] = 'Numéro de téléphone';
$lang['Action not allowed'] = 'Action non autorisée';
$lang['Field required.'] = 'Champ requis.';
$lang['Passwords do not match.'] = 'Les mots de passe ne correspondent pas.';
$lang['No user selected'] = "Pas d'utilisateur sélectionné";
$lang['Delete this folder'] = 'Supprimer ce dossier';
$lang['Loading'] = 'Chargement';
$lang['Connected'] = 'Connecté';
$lang['Disconnected'] = 'Déconnecté';
$lang['No group detected, add one first.'] = "Aucun groupe détecté, ajouter d'abord un groupe.";
$lang['No group selected.'] = 'Pas de groupe sélectionné.';
$lang['From'] = 'De';
$lang['To'] = 'Vers';
$lang['Inserted'] = 'Inséré';
$lang['Date'] = 'Date';
$lang['Sending failed'] = "L'envoi a échoué";
$lang['Sent, no report'] = 'Envoi OK - Pas de rapport';
$lang['Sent, waiting for report'] = 'Envoi OK - Patienter pour le rapport';
$lang['Delivered'] = 'Livré';
$lang['Pending'] = 'En attente';
$lang['Unknown'] = 'Inconnu';

$lang['Country calling code'] = 'Indicatif tél. international';

$lang['Conversation sort'] = 'Tri des conversations';

$lang['Data per page'] = 'Données par page';
$lang['Used for paging in message and phonebook'] = 'Utilisé pour la pagination des message et répertoire';

$lang['Permanent delete'] = 'Suppression définitive';
$lang['Disable'] = 'Désactiver';
$lang['Always move to trash first'] = 'Toujours déplacer dans la corbeille en premier';
$lang['Enable'] = 'Activer';

$lang['User settings'] = "Configuration de l'utilisateur";
$lang['General'] = 'Général';
$lang['Personal'] = 'Personnel';

$lang['Signature'] = 'Signature';
$lang['Max. 50 characters'] = 'Max. 50 caractères';
$lang['Signature is added at the end of the message.'] = 'La signature est ajoutée à la fin du message.';
$lang['Language'] = 'Langue';
$lang['Yes'] = 'Oui';
$lang['No'] = 'Non';
$lang['Default'] = 'Par défaut';
$lang['Delivery Report'] = 'Accusé de réception';

$lang['Delete copy (prevents duplicates).'] = 'Supprimer la copie (évite les doublons).';
$lang['You are about to resend {0} message(s).'] = 'Vous êtes sur le point de renvoyer {0} message(s).';

// Kalkun Controller
$lang['Outgoing SMS disabled. Contact system administrator.'] = "SMS sortants désactivés. Contactez l'administrateur système.";
$lang['Wrong password'] = 'Mot de passe incorrect';
$lang['Username already taken'] = "Nom d'utilisateur déjà utilisé";
$lang['Settings saved successfully.'] = 'Paramètres sauvegardés.';
// Users Controller
$lang['Access denied.'] = 'Accès refusé.';
$lang['User updated successfully.'] = 'Utilisateur mis à jour.';
$lang['User added successfully.'] = 'Utilisateur ajouté.';
// Pluginss Controller
$lang['Access denied. Only administrators are allowed to manage plugins.'] = 'Accès refusé. Seul un administrateur est autorisé à gérer les plugins.';
$lang['Plugin {0} installed successfully.'] = 'Plugin {0} installé avec succès.';
$lang['Plugin {0} uninstalled successfully.'] = 'Plugin {0} désinstallé avec succès.';
$lang['Installed']['Plural'] = 'Installés';
$lang['Available']['Plural'] = 'Disponibles';
// Phonebook Controller
$lang['{0,number,integer} contacts imported successfully.'] = '{0,number,integer} contacts importés avec succès.';
$lang['Contact updated successfully.'] = 'Contact mis à jour.';
$lang['Contact added successfully.'] = 'Contact ajouté.';
// Gammu Model
$lang['Message queued.'] = "Message mis en file d'attente.";
$lang['Parameter invalid.'] = 'Paramètre invalide.';

$lang['403 Forbidden'] = '403 Interdit';

$lang['Close'] = 'Fermer';
$lang['Previous'] = 'Précédent';
$lang['Next'] = 'Suivant';
$lang['Continue'] = 'Continuer';
$lang['Submit']['form'] = 'Valider';
$lang['Log in'] = 'Se connecter';
$lang['Username or password are incorrect.'] = 'Nom d\'utilisateur ou mot de passe incorrects.';
$lang['Token already generated and still active.'] = 'Token déjà généré et encore actif.';
$lang['To reset your Kalkun password please visit {0}'] = 'Pour réinitialiser votre mot de passe Kalkun, veuillez vous rendre à {0}';
$lang['If you are a registered user, a SMS has been sent to you.'] = 'Si vous êtes un utilisateur inscrit, un SMS vous a été envoyé.';
$lang['Password changed successfully.'] = 'Mot de passe modifié avec succès.';
$lang['Token invalid.'] = 'Token invalide.';
$lang['Password reset'] = 'Réinitialisation du mot de passe';
$lang['or'] = 'ou';
$lang['Please enter your username and password'] = 'Veuillez entrer le nom d\'utilisateur et mot de passe';
$lang['Remember me'] = 'Se souvenir de moi';
$lang['Installation'] = 'Installation';
$lang['Installation steps'] = 'Etapes d\'installation';
$lang['Welcome screen'] = 'Ecran d\'accueil';
$lang['Requirements check'] = 'Vérification des prérequis';
$lang['Database setup'] = 'Configuration de la base de données';
$lang['Final configuration steps'] = 'Etapes finales de configuration';
$lang['Ok'] = 'Ok';
$lang['Missing'] = 'Manquant';
$lang['Found'] = 'Trouvé';
$lang['Successful'] = 'Réussi';
$lang['Failed'] = 'En échec';
$lang['Kalkun installation assistant'] = 'Assistant d\'installation de Kalkun';
$lang['This welcome screen'] = 'Cet écran d\'accueil';
$lang['Database installation or upgrade'] = 'Installation ou mise à jour de la base de données';
$lang['Keyboard shortcuts'] = 'Raccourcis clavier';
$lang['Jumping'] = 'Sauts';
$lang['{0} then {1}:'] = '{0} puis {1}:';
$lang['Navigation'] = 'Navigation';
$lang['Back to conversation list'] = 'Retour à la liste des conversations';
$lang['Highlight prev/next'] = 'Surligner préc/suivant';
$lang['Open prev/next (message only)'] = 'Ouvrir préc/suivant (message seulement)';
$lang['{0} or {1}:'] = '{0} ou {1}:';
$lang['Open'] = 'Ouvrir';
$lang['Selection'] = 'Sélection';
$lang['Select'] = 'Sélectionner';
$lang['Actions'] = 'Actions';
$lang['Move selected'] = 'Déplacer la sélection';
$lang['Delete selected'] = 'Supprimer la sélection';
$lang['Message details'] = 'Détails du message';
$lang['Application'] = 'Application';
$lang['Open shortcut help'] = 'Ouvrir l\'aide des raccourcis';
$lang['Error'] = 'Erreur';
$lang['Please specify a valid mobile phone number'] = 'Veuillez entrer un numéro de mobile valide';
$lang['Go to {0}'] = 'Aller à {0}';
$lang['Please enter a name for your message. It should be unique.'] = 'Veuillz entrer un nom pour votre message. Il doit être unique.';
$lang['Are you sure? This will overwrite the previous message.'] = 'Êtes-vous sûr(e) ? Cela va écraser le message précédent.';
$lang['PHP Frontend for gammu-smsd'] = 'PHP Frontend for gammu-smsd';
$lang['Authors'] = 'Auteurs';
$lang['See {0} page'] = 'Voir la page {0}';
$lang['Version'] = 'Version';
$lang['Released'] = 'Livré';
$lang['License'] = 'Licence';
$lang['Homepage'] = 'Homepage';
$lang['Add a new folder'] = 'Ajouter un nouveau dossier';
$lang['Plugins'] = 'Plugins';
$lang['No data'] = 'Pas de données';
$lang['Select field'] = 'Sélectionner le champ';
$lang['Delete folder'] = 'Supprimer le dossier';
$lang['Role'] = 'Rôle';
$lang['Delete users'] = 'Supprimer utilisateurs';
$lang['Theme'] = 'Thème';
$lang['Background image'] = 'Image de fond';
$lang['Ascending'] = 'Croissant';
$lang['Descending'] = 'Décroissant';
$lang['Value is too short.'] = 'La valeur estr trop courte.';
$lang['Select group name'] = 'Sélectionner le nom du group';
$lang['Uninstall'] = 'Désinstaller';
$lang['Install'] = 'Installer';
$lang['Author'] = 'Auteur';
$lang['No plugin available.'] = 'Pas de plugin disponible.';
$lang['No plugin installed.'] = 'Pas de plugin installé.';
$lang['Retrying now'] = 'Nouvel essai en cours';
$lang['{0} character(s) / {1} message(s)'] = '{0} caractères(s) / {1} message(s)';
$lang['{0} message(s) deleted'] = '{0} message(s) supprimé(s)';
$lang['{0} conversation(s) recovered'] = '{0} conversation(s) récupérées';
$lang['Messages moved successfully'] = 'Messages déplacés avec succès';
$lang['Outgoing message cannot be spam'] = 'Les messages sortant ne peuvent pas être du spam';
$lang['Spam reported'] = 'Déclaré comme Spam';
$lang['Message(s) marked non-spam'] = 'Message(s) marqué(s) "non-spam"';
$lang['{0} conversation(s) deleted'] = '{0} conversation(s) supprimées';
$lang['{0} conversation(s) moved'] = '{0} conversation(s) déplacées';
$lang['Value is too long.'] = 'La valeur est trop longue.';
$lang['Updated'] = 'Mis(e) à jour';
$lang['Import'] = 'Importer';
$lang['Reset search'] = 'Réinit. la rech.';
$lang['No.']['Number abbreviation'] = 'Num.';
$lang['Insertion date'] = 'Date d\'insertion';
$lang['Control'] = 'Contrôle';
$lang['Plugin {0} is not installed.'] = 'Le plugin {0} n\'est pas installé.';
$lang['Value must be a number.'] = 'La valeur doit être un nombre.';
$lang['{0} part messages'] = '{0} part messages';
$lang['Content'] = 'Contenu';
$lang['No results for {0}'] = 'Pas de résultat pour {0}';
$lang['Failure to inject message into Gammu with gammu-smsd-inject. See kalkun logs.'] = "Echec d'injection du message dans Gammu avec gammu-smsd-inject. Voir le journal de Kalkun.";
$lang['Group'] = 'Groupe';
$lang['Delete the original message (prevents duplicates).'] = "Supprimer le message d'origine (évite les doublons).";
$lang['Delete permanently'] = 'Suppr. définitivement';
$lang['Retrying in {0} seconds.'] = 'Nouvel essai dans {0} secondes.';
$lang['Signal'] = 'Signal';
$lang['Battery'] = 'Batterie';
$lang['Writable'] = 'Accessible en écriture';
$lang['Read-only'] = 'En lecture seule';
$lang['Inbox Master'] = 'Inbox Master';
$lang['Network error.'] = 'Erreur réseau.';
$lang['{0}%'] = '{0}%';
$lang['Item deleted.'] = 'Elément supprimé.';
$lang['Installation has been disabled by the administrator.
To enable access to it, create a file named {0} in this directory of the server: {1}.
Otherwise you may log-in at {2}.'] = "L'installation a été désactivée par l'administrateur.
Pour activer l'accès, créer un fichier nommé {0} dans ce répertoire du serveur: {1}.
Sinon, vous pouvez aussi vous connecter à {2}.";
$lang['There is no message in this conversation.'] = "Il n'y a pas de message dans cette conversation.";
$lang['Check again'] = 'Vérifier à nouveau';
$lang['Password modification forbidden in demo mode.'] = 'Modification du mot de passe interdite en mode "démo".';
$lang['Settings saved successfully (except username for kalkun user which can\'t be changed in demo mode)'] = 'Settings saved successfully (except username for kalkun user which can\'t be changed in demo mode)';
$lang['Modification of username of "kalkun" user forbidden in demo mode. Username was restored.'] = 'Modification of username of "kalkun" user forbidden in demo mode. Username was restored.';
$lang['Process incoming messages'] = 'Process incoming messages';
$lang['Changing role of "kalkun" user forbidden in demo mode. Role was restored.'] = 'Changing role of "kalkun" user forbidden in demo mode. Role was restored.';
