<?php

/*
 * Romanian language
 */

$lang['text_rest_invalid_api_key'] = 'Cheie API invalidă %s'; // %s is the REST API key
$lang['text_rest_invalid_credentials'] = 'Acreditări invalide';
$lang['text_rest_ip_denied'] = 'IP respins';
$lang['text_rest_ip_unauthorized'] = 'IP neautorizat';
$lang['text_rest_unauthorized'] = 'Neautorizat';
$lang['text_rest_ajax_only'] = 'Doar cererile AJAX sunt acceptate';
$lang['text_rest_api_key_unauthorized'] = 'Această cheie API nu are acees la controller-ul solicitat';
$lang['text_rest_api_key_permissions'] = 'Această cheie API nu are suficiente permisiuni';
$lang['text_rest_api_key_time_limit'] = 'Această cheie API a atins limita de timp pentru această metodă';
$lang['text_rest_ip_address_time_limit'] = 'This IP Address has reached the time limit for this method'; //todo translate
$lang['text_rest_unknown_method'] = 'Metodă necunoscută';
$lang['text_rest_unsupported'] = 'Protocol neacceptat';
