<?php
/*
 * Italian language
 */
$lang['text_rest_invalid_api_key'] = 'API key %s non valida'; // %s is the REST API key
$lang['text_rest_invalid_credentials'] = 'Credenziali non valide';
$lang['text_rest_ip_denied'] = 'IP non consentito';
$lang['text_rest_ip_unauthorized'] = 'IP non autorizzato';
$lang['text_rest_unauthorized'] = 'Non autorizzato';
$lang['text_rest_ajax_only'] = 'Sono ammesse solo richieste AJAX';
$lang['text_rest_api_key_unauthorized'] = 'Questa API key non ha accesso al controller richiesto';
$lang['text_rest_api_key_permissions'] = 'Questa API key non dispone di autorizzazioni sufficienti';
$lang['text_rest_api_key_time_limit'] = 'Questa API key ha raggiunto il limite di tempo per questo metodo';
$lang['text_rest_ip_address_time_limit'] = 'Questo indirizzo IP ha raggiunto il limite di tempo per questo metodo';
$lang['text_rest_unknown_method'] = 'Metodo sconosciuto';
$lang['text_rest_unsupported'] = 'Protocollo non supportato';
