<?php
// Norsk oversettelse
// Author: Syvert Fossdal <syvert@online.no>

// Global
$lang['Dashboard'] = 'Oversikt';
$lang['Folders'] = 'Mapper';
$lang['My folders'] = 'Mine mapper';

$lang['Compose'] = 'Ny melding';
$lang['Inbox'] = 'Innboks';
$lang['Outbox'] = 'Utboks';
$lang['Sent items'] = 'Sendte meldinger';
$lang['Sending error'] = 'Feil ved sending';
$lang['Trash'] = 'Søppel';
$lang['Spam'] = 'Spam';
$lang['Add'] = 'Legg til';
$lang['Action'] = 'Handling';

$lang['Phonebook'] = 'Kontakter';
$lang['Settings'] = 'Instillinger';
$lang['Filters'] = 'Filter';
$lang['About {0}'] = 'Om {0}';
$lang['Logout'] = 'Logg ut';

// Dashboard
$lang['Statistics'] = 'Statistikker';
$lang['System information'] = 'System informasjon';
$lang['Alerts'] = 'Advarsler';
$lang['Operating system'] = 'Operativ system';
$lang['Gammu version'] = 'Gammu versjon';
$lang['Gammu DB schema'] = 'Gammu DB schema';
$lang['Modem IMEI'] = 'Modem IMEI';

// Phonebook
$lang['Contact'] = 'Kontakt';
$lang['All contacts'] = 'Alle kontakter';
$lang['Send to all contacts'] = 'Send til alle kontakter';
$lang['Add to group'] = 'Legg til i gruppe';
$lang['Delete from group'] = 'Slett fra gruppe';
$lang['Select add contact method'] = 'Velg metode for å legge til kontakt';
$lang['Manual input'] = 'Legg til manuelt';
$lang['Manually add contact using contact form'] = 'Legg til kontakt via skjema';
$lang['From CSV file'] = 'Fra CSV fil';
$lang['Import contact from CSV format file'] = 'Importer kontakt fra en CSV fil';
$lang['CSV file'] = 'CSV fil';
$lang['The CSV file must be in valid format'] = 'CVS-fila må være i et gyldig format';
$lang['Are you sure you want to delete {0} contact(s)?'] = 'Er du sikker på at du vil slette {0} kontakt(er)?';
$lang['valid example'] = 'Eksempel på gyldig format';

// Message
$lang['Message'] = 'Melding';
$lang['Send to'] = 'Send til';
$lang['Reply'] = 'Svar';
$lang['Forward'] = 'Videresend';
$lang['Forward to'] = 'Videresend til';
$lang['Move to'] = 'Flytt til';
$lang['Select folder'] = 'Velg mappe';
$lang['Delete'] = 'Slett';
$lang['Click to delete this folder'] = 'Klikk for å slette denne mappen';
$lang['Recover'] = 'Gjenopprett';

$lang['Send date'] = 'Send dato';
$lang['Now'] = 'Nå';
$lang['At date and time'] = 'På dato og tidspunkt';
$lang['After a delay'] = 'Med forsinkelse';

$lang['Input manually'] = 'Skriv nummer';

$lang['Add folder'] = 'Legg til mappe';
$lang['Folder name'] = 'Mappenavn';
$lang['Cancel'] = 'Avbryt';
$lang['Save'] = 'Lagre';
$lang['Rename'] = 'Gi nytt navn';
$lang['Rename folder'] = 'Gi nytt navn til mappe';
$lang['Click to rename this folder'] = 'Klikk for å gi mappen nytt navn';

$lang['This folder and all messages in it will be deleted permanently and cannot be recovered. Are you sure?'] = 'Denne mappen og alt innhold vil bli slettet permanent og kan ikke gjenopprettes. Er du sikker?';

$lang['There is no message in {0}.'] = 'Det er ingen meldinger i {0}.';
$lang['There is no message in this folder.'] = 'Det er ingen meldinger i denne mappen.';

$lang['Delete all'] = 'Slett alle';
$lang['Are you sure? This will affect all conversations.'] = 'Er du sikker? Dette vil gjelde alle samtaler.';

$lang['Select all'] = 'Velg alle';
$lang['Deselect all'] = 'Velg bort alle';
$lang['Refresh'] = 'Oppdater';

$lang['Report spam'] = 'Rapporter spam';
$lang['Not spam'] = 'Ikke spam';


$lang['SMSC'] = 'SMSC';
$lang['Part'] = 'Del';
$lang['Validity'] = 'Gyldighet';
$lang['default'] = 'standard';
$lang['5 minutes'] = '5 minutter';
$lang['10 minutes'] = '10 minutter';
$lang['30 minutes'] = '30 minutter';
$lang['1 hour'] = '1 time';
$lang['2 hours'] = '2 timer';
$lang['4 hours'] = '4 timer';
$lang['12 hours'] = '12 timer';
$lang['1 day'] = '1 dag';
$lang['2 days'] = '2 dager';
$lang['5 days'] = '5 dager';
$lang['1 week'] = '1 uke';
$lang['2 weeks'] = '2 uker';
$lang['4 weeks'] = '4 uker';
$lang['maximum'] = 'maks';

$lang['SMS type'] = 'SMS type';
$lang['Normal'] = 'Normal';
$lang['Flash'] = 'Flash';
$lang['WAP push link'] = 'WAP push link';
$lang['URL'] = 'URL';

$lang['Ads is active'] = 'Reklame er aktivert';
$lang['Check DND'] = 'Sjekk DND';
$lang['Insert'] = 'Sett inn';

$lang['Canned responses'] = 'Faste svar';
$lang['There are no canned responses. Continue to save your present message as canned response.'] = 'Det finnes ingen faste svar. Fortsett for å lagre din nåværende melding som et fast svar.';
$lang['Choose response'] = 'Velg svar';
$lang['Saving...'] = 'Lagrer...';
$lang['Are you sure?'] = 'Er du sikker?';

// Others
$lang['Amount'] = 'Beløp';
$lang['times']['repetition'] = 'ganger';
$lang['Hour(s)'] = 'Time(er)';
$lang['Minutes'] = 'Minutter';
$lang['No result.'] = 'Ingen resultat.';
$lang['See conversation'] = 'Se samtale';

$lang['Search'] = 'Søk';
$lang['Advanced search'] = 'Avansert søk';
$lang['Folder'] = 'Mappe';
$lang['All'] = 'Alle';
$lang['Date from'] = 'Dato fra';
$lang['Date to'] = 'Dato til';
$lang['Status'] = 'Status';
$lang['Paging'] = 'Søker';
$lang['{0} per page'] = '{0} per side';

$lang['Resend'] = 'Send på nytt';
$lang['Public contacts'] = 'Offentlige kontakter';
$lang['Set as public contact'] = 'Gjør kontakten offentlig';
$lang['My contacts'] = 'Mine kontakter';
$lang['Public groups'] = 'Offentlige grupper';
$lang['Set as public group'] = 'Gjør gruppen offentlig';
$lang['My groups'] = 'Mine grupper';
$lang['Incoming SMS'] = 'Innkommende SMS';
$lang['Outgoing SMS'] = 'Utgående SMS';
$lang['Delete all messages now'] = 'Slett alle beskjeder nå';
$lang['Delete contact(s) confirmation'] = 'Slett kontakt(er) bekreftelse';
$lang['Should be a valid URL'] = 'Må være en gyldig URL';
$lang['Import from file'] = 'Importer fra fil';

// Messages controller
$lang['Outgoing SMS disabled.'] = 'Utgående SMS deaktivert.';
$lang['A number was found in DND Resitry. SMS sending was skipped for it.'] = 'Et nummer ble funnet i DND registeret. SMS ble ikke sendt til dette nummeret.';
$lang['Message delivered successfully to user inbox.'] = 'Meldingen ble levert til brukers innboks.';
$lang['Copy of the message was placed in the outbox and is ready for delivery.'] = 'Kopi av meldingen ble lagt i utboks og er klar til levering.';
$lang['No number found. SMS not sent.'] = 'Ingen nummer ble funnet. SMS ble ikke sendt';
$lang['Only administrators can permanently delete messages.'] = 'Bare administratorer kan slette melding permanent.';

// Setting
$lang['Current password'] = 'Nåværende passord';
$lang['Forgot your password?'] = 'Glemt passord?';
$lang['New password'] = 'Nytt passord';
$lang['Must be at least 6 characters long'] = 'Må være minst 6 karakterer langt';

$lang['Enter your new password'] = 'Skriv inn nytt passord';

$lang['Administrator'] = 'Administrator';
$lang['User']['credentials'] = 'Bruker';

$lang['Create a new filter'] = 'Lag nytt filter';
$lang['Has the words'] = 'Har ordene';

// SMS Content/Member
$lang['Member'] = 'Medlem';
$lang['Total member'] = 'Totalt antall medlemmer';
$lang['There is no registered member yet'] = 'Det er ikke registrert noen medlemmer enda';

// tni contribution
$lang['Add contact'] = 'Legg til kontakt';
$lang['Send message'] = 'Send melding';
$lang['Send and repeat'] = 'Send og repeter';
$lang['Sending'] = 'Sender';
$lang['Insert name from contact list'] = 'Skriv inn navn fra kontaktlisten';
$lang['Delete group(s) confirmation'] = 'Slett gruppe(r) bekreftelse';
$lang['Delete group(s)?
All their contacts will also be deleted.'] = 'Slett gruppe(r)?
Alle kontaktene i gruppen vil også bli slettet.';
$lang['Create group'] = 'Lag gruppe';
$lang['Group name'] = 'Gruppenavn';
$lang['Groups'] = 'Grupper';
$lang['Manage groups'] = 'Behandle grupper';
$lang['Manage group'] = 'Behandle gruppe';
$lang['Manage contact'] = 'Behandle kontakt';
$lang['Type group name'] = 'Skriv gruppenavn';
$lang['No item selected.'] = 'Ingenting valgt.';
$lang['No contact selected.'] = 'Ingen kontakter valgt.';
$lang['Compose SMS'] = 'Lag ny SMS';
$lang['Contacts'] = 'Kontakter';
$lang['Back to {0}'] = 'Tilbake til {0}';
$lang['Show details'] = 'Vis detaljer';
$lang['Hide details'] = 'Skjul detaljer';
$lang['Search contacts'] = 'Søk i kontakter';
$lang['Search messages'] = 'Søk i meldinger';
$lang['Edit'] = 'Rediger';
$lang['All form fields are required.'] = 'Alle feltene må fylles ut.';
$lang['Name'] = 'Navn';
$lang['Telephone number'] = 'Telefonnummer';
$lang['Email ID'] = 'Epost ID';
$lang['Enable email forwarding'] = 'Aktiver videresending til epost';
$lang['{0} remaining'] = '{0} gjenstående';
$lang['{0} ago'] = '{0} siden';
$lang['Edit contact'] = 'Rediger kontakt';
$lang['Contact not found'] = 'Kontakt ikke funnet';
$lang['No contacts in the database.'] = 'Ingen kontakter i databasen.';
$lang['Add user'] = 'Legg til bruker';
$lang['Edit user'] = 'Rediger bruker';
$lang['User']['default'] = 'Bruker';
$lang['Users'] = 'Brukere';
$lang['This deletes the selected users and all their messages and contacts.'] = 'Dette sletter de valgte brukerne og alle deres beskjeder og kontakter.';
$lang['User not found'] = 'Bruker ikke funnet';
$lang['No users in the database.'] = 'Ingen brukere i databasen.';
$lang['Username'] = 'Brukernavn';
$lang['Password'] = 'Passord';
$lang['Search user'] = 'Søk i brukere';
$lang['Confirm password'] = 'Bekreft passord';
$lang['Phone number'] = 'Telefonnummer';
$lang['Action not allowed'] = 'Handling ikke tillatt';
$lang['Field required.'] = 'Felt påkrevd.';
$lang['Passwords do not match.'] = 'Passordene er ikke like.';
$lang['No user selected'] = 'Ingen bruker valgt';
$lang['Delete this folder'] = 'Slett denne mappen';
$lang['Loading'] = 'Laster';
$lang['Connected'] = 'Tilkoblet';
$lang['Disconnected'] = 'Frakoblet';
$lang['No group detected, add one first.'] = 'Ingen grupper funnet, legg til en først.';
$lang['No group selected.'] = 'Ingen gruppe valgt.';
$lang['From'] = 'Fra';
$lang['To'] = 'Til';
$lang['Inserted'] = 'Satt inn';
$lang['Date'] = 'Dato';
$lang['Sending failed'] = 'Sending feilet';
$lang['Sent, no report'] = 'Sendt, ingen bekreftelse';
$lang['Sent, waiting for report'] = 'Sendt, venter på bekreftelse';
$lang['Delivered'] = 'Levert';
$lang['Pending'] = 'Avventer';
$lang['Unknown'] = 'Ukjent';
$lang['Not set yet'] = 'Ikke valgt enda';

$lang['Country calling code'] = 'Landskode';

$lang['Conversation sort'] = 'Type samtale';

$lang['Data per page'] = 'Data per side';
$lang['Used for paging in message and phonebook'] = 'Brukt til personsøking i melding og kontakter';

$lang['Permanent delete'] = 'Slett permanent';
$lang['Disable'] = 'Deaktiver';
$lang['Always move to trash first'] = 'Alltid flytt til papirkurv først';
$lang['Enable'] = 'Aktiver';

$lang['User settings'] = 'Brukerinnstillinger';
$lang['General'] = 'Generelt';
$lang['Personal'] = 'Personlig';

$lang['Signature'] = 'Signatur';
$lang['Max. 50 characters'] = 'Maks 50 tegn';
$lang['Signature is added at the end of the message.'] = 'Signaturen blir lagt til på slutten av meldingen.';
$lang['Language'] = 'Språk';
$lang['Yes'] = 'Ja';
$lang['No'] = 'Nei';
$lang['Default'] = 'Standard';
$lang['Delivery Report'] = 'Leveringsrapport';

$lang['Delete copy (prevents duplicates).'] = 'Slett kopi (hindrer duplikater).';
$lang['You are about to resend {0} message(s).'] = 'Du sender {0} melding(er).';

// Kalkun Controller
$lang['Outgoing SMS disabled. Contact system administrator.'] = 'Utgående SMS er deaktivert. Kontakt systemadministrator.';
$lang['Wrong password'] = 'Feil passord';
$lang['Username already taken'] = 'Brukernavn opptatt';
$lang['Settings saved successfully.'] = 'Innstillnger lagret.';
// Users Controller
$lang['Access denied.'] = 'Ingen adgang.';
$lang['User updated successfully.'] = 'Bruker oppdatert.';
$lang['User added successfully.'] = 'Bruker lagt til.';
// Pluginss Controller
$lang['Access denied. Only administrators are allowed to manage plugins.'] = 'Ingen adgang. Bare administratorer kan behandle plugins.';
$lang['Plugin {0} installed successfully.'] = 'Plugin {0} installert.';
$lang['Plugin {0} uninstalled successfully.'] = 'Plugin {0} avinstallert.';
$lang['Installed']['Plural'] = 'Installert';
$lang['Available']['Plural'] = 'Tilgjengelig';
// Phonebook Controller
$lang['{0,number,integer} contacts imported successfully.'] = '{0,number,integer} kontakter importert.';
$lang['Contact updated successfully.'] = 'Kontakt oppdatert.';
$lang['Contact added successfully.'] = 'Kontakt lagt til.';
// Gammu Model
$lang['Message queued.'] = 'Melding sendt til kø.';
$lang['Parameter invalid.'] = 'Ugyldig parameter.';

$lang['403 Forbidden'] = '403 Forbudt';

$lang['Close'] = 'Lukk';
$lang['Previous'] = 'Forrige';
$lang['Next'] = 'Neste';
$lang['Continue'] = 'Fortsett';
$lang['Submit']['form'] = 'Send';
$lang['Log in'] = 'Logg inn';
$lang['Username or password are incorrect.'] = 'Brukernavn eller passord er feil.';
$lang['Token already generated and still active.'] = 'Token allerede generert og fremdeles aktiv.';
$lang['To reset your Kalkun password please visit {0}'] = 'For å resette ditt Kalkun passord, vennligst besøk {0}';
$lang['If you are a registered user, a SMS has been sent to you.'] = 'Hvis du er en registrert bruker, har det blitt sendt en SMS til deg.';
$lang['Password changed successfully.'] = 'Passord er endret.';
$lang['Token invalid.'] = 'Token ugyldig.';
$lang['Password reset'] = 'Sett nytt passord';
$lang['or'] = 'eller';
$lang['Please enter your username and password'] = 'Vennligst skriv inn ditt brukernavn og passord';
$lang['Remember me'] = 'Husk meg';
$lang['Installation'] = 'Installasjon';
$lang['Installation steps'] = 'Installasjonstrinn';
$lang['Welcome screen'] = 'Velkomstside';
$lang['Requirements check'] = 'Sjekk av forutsetninger';
$lang['Database setup'] = 'Installasjon av database';
$lang['Final configuration steps'] = 'Siste installasjonstrinn';
$lang['Ok'] = 'Ok';
$lang['Missing'] = 'Mangler';
$lang['Found'] = 'Funnet';
$lang['Successful'] = 'Suksess';
$lang['Failed'] = 'Feilet';
$lang['Kalkun installation assistant'] = 'Kalkun installasjonsassistent';
$lang['This welcome screen'] = 'Denne velkomstsiden';
$lang['Database installation or upgrade'] = 'Installasjon av database eller oppgradering';
$lang['Keyboard shortcuts'] = 'Tastatur snarveier';
$lang['Jumping'] = 'Hopp over';
$lang['{0} then {1}:'] = '{0} så {1}:';
$lang['Navigation'] = 'Navigasjon';
$lang['Back to conversation list'] = 'Tilbake til samtaleliste';
$lang['Highlight prev/next'] = 'Uthev forrige/neste';
$lang['Open prev/next (message only)'] = 'Åpne forrige/neste (kun melding)';
$lang['{0} or {1}:'] = '{0} eller {1}:';
$lang['Open'] = 'Åpne';
$lang['Selection'] = 'Valg';
$lang['Select'] = 'Velg';
$lang['Actions'] = 'Handlinger';
$lang['Move selected'] = 'Flytt valgte';
$lang['Delete selected'] = 'Slett valgte';
$lang['Message details'] = 'Meldingsdetaljer';
$lang['Application'] = 'Applikasjon';
$lang['Open shortcut help'] = 'Åpne snarvei til hjelp';
$lang['Error'] = 'Feil';
$lang['Please specify a valid mobile phone number'] = 'Vennligst spesifiser et gyldig telefonnummer';
$lang['Go to {0}'] = 'Gå til {0}';
$lang['Please enter a name for your message. It should be unique.'] = 'Vennligst skriv inn et navn på meldingen. Dette bør være unikt.';
$lang['Are you sure? This will overwrite the previous message.'] = 'Er du sikker? Dette vil overskrive forrige melding.';
$lang['PHP Frontend for gammu-smsd'] = 'PHP Frontend for gammu-smsd';
$lang['Authors'] = 'Forfattere';
$lang['See {0} page'] = 'Se {0} side';
$lang['Version'] = 'Versjon';
$lang['Released'] = 'Sluppet';
$lang['License'] = 'Lisens';
$lang['Homepage'] = 'Hjemmeside';
$lang['Add a new folder'] = 'Legg til ny mappe';
$lang['Plugins'] = 'Plugins';
$lang['No data'] = 'Ingen data';
$lang['Select field'] = 'Velg felt';
$lang['Delete folder'] = 'Slett mappe';
$lang['Role'] = 'Rolle';
$lang['Delete users'] = 'Slett brukere';
$lang['Theme'] = 'Tema';
$lang['Background image'] = 'Bakgrunnsbilde';
$lang['Ascending'] = 'Stigende';
$lang['Descending'] = 'Synkende';
$lang['Value is too short.'] = 'For kort verdi.';
$lang['Select group name'] = 'Velg gruppenavn';
$lang['Uninstall'] = 'Avinstaller';
$lang['Install'] = 'Installer';
$lang['Author'] = 'Forfatter';
$lang['No plugin available.'] = 'Ingen plugin tilgjengelig.';
$lang['No plugin installed.'] = 'Ingen plugin installert.';
$lang['Retrying now'] = 'Prøver på nytt nå';
$lang['{0} character(s) / {1} message(s)'] = '{0} tegn / {1} beskjed(er)';
$lang['{0} message(s) deleted'] = '{0} beskjed(er) slettet';
$lang['{0} conversation(s) recovered'] = '{0} samtale(r) gjenopprettet';
$lang['Messages moved successfully'] = 'Beskjeder flyttet';
$lang['Outgoing message cannot be spam'] = 'Utgående meldinger kan ikke være spam.';
$lang['Spam reported'] = 'Spam rapportert';
$lang['Message(s) marked non-spam'] = 'Beskjed(er) merket som ikke spam';
$lang['{0} conversation(s) deleted'] = '{0} samtale(r) slettet';
$lang['{0} conversation(s) moved'] = '{0} samtale(r) flyttet';
$lang['Value is too long.'] = 'For mange tegn.';
$lang['Updated'] = 'Oppdater';
$lang['Import'] = 'Importer';
$lang['Reset search'] = 'Resett søk';
$lang['No.']['Number abbreviation'] = 'Nr.';
$lang['Insertion date'] = 'Innsettelsesdato';
$lang['Control'] = 'Kontroll';
$lang['Plugin {0} is not installed.'] = 'Plugin {0} er ikke installert.';
$lang['Value must be a number.'] = 'Verdien må være et tall.';
$lang['{0} part messages'] = '{0} delbeskjeder';
$lang['Content'] = 'Innhold';
$lang['No results for {0}'] = 'Ingen resultater for {0}';
$lang['Failure to inject message into Gammu with gammu-smsd-inject. See kalkun logs.'] = 'Feilet i å legge inn melding til Gammu med gammu-smsd-inject.  Se Kalkun logg.';
$lang['Group'] = 'Gruppe';
$lang['Delete the original message (prevents duplicates).'] = 'Slett den opprinnelige meldingen (unngå duplikater).';
$lang['Delete permanently'] = 'Slett permanent';
$lang['Retrying in {0} seconds.'] = 'Prøver på nytt om {0} sekunder.';
$lang['Signal'] = 'Signalstyrke';
$lang['Battery'] = 'Batteri';
$lang['Writable'] = 'Skrivbar';
$lang['Read-only'] = 'Kun lesetilgang';
$lang['Inbox Master'] = 'Innboks Master';
$lang['Network error.'] = 'Netverksfeil.';
$lang['{0}%'] = '{0}%';
$lang['Item deleted.'] = 'Innhold slettet.';
$lang['Installation has been disabled by the administrator.
To enable access to it, create a file named {0} in this directory of the server: {1}.
Otherwise you may log-in at {2}.'] = 'Installasjon har blitt deaktivert av administrator.
får å få tilgang til den, lag en fil med navn {0} i denne mappen på serveren: {1}.
Ellers kan du logge inn på {2}.';
$lang['There is no message in this conversation.'] = 'Det er ingen meldinger i denne samtalen.';
$lang['Check again'] = 'Prøv igjen';
$lang['Password modification forbidden in demo mode.'] = 'Endring av passord er ikke tillatt i demo-mode.';
$lang['Settings saved successfully (except username for kalkun user which can\'t be changed in demo mode)'] = 'Innstillnger lagret (bortsett fra brukernavn for kalkun bruker, som ikke kan endres i demo-mode.)';
$lang['Modification of username of "kalkun" user forbidden in demo mode. Username was restored.'] = 'Endring av brukernavn "kalkun" er ikke tillatt i demo-mode. Brukernavn ble gjenopprettet.';
$lang['Process incoming messages'] = 'Process incoming messages';
$lang['Changing role of "kalkun" user forbidden in demo mode. Role was restored.'] = 'Changing role of "kalkun" user forbidden in demo mode. Role was restored.';
