<?php
defined('BASEPATH') OR exit('No direct script access allowed');

// phpcs:disable CodeIgniter.Commenting.InlineComment.WrongStyle
/*
|--------------------------------------------------------------------------
| CONFIGURATION
|--------------------------------------------------------------------------
|
| uid - identifier of which user sent the autoreply, uid 1 is the default value
| message - the message you want to sent
|
*/
// phpcs:enable
$config['uid'] = '1';
$config['message'] = 'Thanks for sending me the message';
