<?php

$lang['{0} taken into account.'] = '{0} taken into account.';
$lang['{0} taken into account. To opt-in again, send "{1}".'] = '{0} taken into account. To opt-in again, send "{1}".';
$lang['{0} taken into account. To opt-out, send "{1}".'] = '{0} taken into account. To opt-out, send "{1}".';
$lang['Request not valid ({0}). Send "{1} or {2} <type>". Possible values for <type> are: {3}. For example "{4}".'] = 'Request not valid ({0}). Send "{1} or {2} <type>". Possible values for <type> are: {3}. For example "{4}".';
$lang['Request not valid ({0}). Send "{1} <type>". Possible values for <type> are: {2}. For example "{3}".'] = 'Request not valid ({0}). Send "{1} <type>". Possible values for <type> are: {2}. For example "{3}".';
$lang['Request not valid ({0}). Send "{1}" or "{2}". For example "{3}".'] = 'Request not valid ({0}). Send "{1}" or "{2}". For example "{3}".';
$lang['Request not valid ({0}). Send "{1}".'] = 'Request not valid ({0}). Send "{1}".';
$lang['Stop Manager records'] = 'Stop Manager records';
$lang['Add STOP record'] = 'Add STOP record';
$lang['Type'] = 'Type';
$lang['Original opt-out SMS'] = 'Original opt-out SMS';
