<?php

/*
 * Greek language
 */

$lang['text_rest_invalid_api_key'] = 'Λάθος API key %s'; // %s είναι το REST API key
$lang['text_rest_invalid_credentials'] = 'Μή έγκυρα διαπιστευτήρια';
$lang['text_rest_ip_denied'] = 'Άρνηση πρόσβασης της διεύθηνσης IP';
$lang['text_rest_ip_unauthorized'] = 'Μη εξουσιοδοτημένη διεύθυνση IP';
$lang['text_rest_unauthorized'] = 'Άρνηση Πρόσβασης. Μη εξουσιοδοτημένο';
$lang['text_rest_ajax_only'] = 'Μόνο AJAX requests επιτρέπονται';
$lang['text_rest_api_key_unauthorized'] = 'Αυτό το API key δεν έχει πρόσβαση στον συγκεκριμένο controller';
$lang['text_rest_api_key_permissions'] = 'Αυτό το API key δεν έχει αρκετά δικαιώματα';
$lang['text_rest_api_key_time_limit'] = 'Αυτό το API key έχει φτάσει στο μέγιστο όριο requests για την συγκεκριμένη μέθοδο';
$lang['text_rest_ip_address_time_limit'] = 'This IP Address has reached the time limit for this method'; //todo translate
$lang['text_rest_unknown_method'] = 'Άγνωστη μέθοδος';
$lang['text_rest_unsupported'] = 'Το συγκεκριμένο πρωτόκολλο δεν υποστηρίζεται';
