<?php
/*
 * Dutch language
 */
$lang['text_rest_invalid_api_key'] = 'Ongeldige API sleutel %s'; // %s is the REST API key
$lang['text_rest_invalid_credentials'] = 'Ongeldige gegevens';
$lang['text_rest_ip_denied'] = 'IP-adres geweigerd';
$lang['text_rest_ip_unauthorized'] = 'IP-adres niet toegestaan';
$lang['text_rest_unauthorized'] = 'Niet toegestaan';
$lang['text_rest_ajax_only'] = 'Alleen AJAX requests zijn toegestaan';
$lang['text_rest_api_key_unauthorized'] = 'De API sleutel heeft geen toegang tot de gevraagde informatie';
$lang['text_rest_api_key_permissions'] = 'De API sleutel heeft niet genoeg bevoegdheden';
$lang['text_rest_api_key_time_limit'] = 'De API sleutel heeft de tijdslimiet bereikt';
$lang['text_rest_ip_address_time_limit'] = 'Het IP-adres heeft de tijdslimiet bereikt';
$lang['text_rest_unknown_method'] = 'Onbekende actie';
$lang['text_rest_unsupported'] = 'Protocol wordt niet ondersteund';
