<?php
/*
 * Korean language
 */
$lang['text_rest_invalid_api_key'] = '유효하지 않은 API 키 : %s'; // %s is the REST API key
$lang['text_rest_invalid_credentials'] = '잘못된 자격 증명';
$lang['text_rest_ip_denied'] = '허용되지 않은 IP';
$lang['text_rest_ip_unauthorized'] = '권한이 없는 IP';
$lang['text_rest_unauthorized'] = '권한이 없음';
$lang['text_rest_ajax_only'] = 'Ajax 요청만 허용됩니다.';
$lang['text_rest_api_key_unauthorized'] = '해당 API 키는 요청된 컨트롤러에 접근되지 않습니다.';
$lang['text_rest_api_key_permissions'] = '해당 API 키는 권한이 없습니다.';
$lang['text_rest_api_key_time_limit'] = '해당 API 키는 메서드의 시간 제한에 도달했습니다.';
$lang['text_rest_ip_address_time_limit'] = '해당 IP 주소는 메서드의 시간 제한에 도달했습니다.';
$lang['text_rest_unknown_method'] = '알 수 없는 메서드입니다.';
$lang['text_rest_unsupported'] = '지원하지 않는 프로토콜입니다.';
