<?php
defined('BASEPATH') OR exit('No direct script access allowed');

// phpcs:disable CodeIgniter.Commenting.InlineComment.WrongStyle
/*
|--------------------------------------------------------------------------
| CONFIGURATION
|--------------------------------------------------------------------------
|
| reg_code - Registration code (Don't use space)
| unreg_code - Unregistration code (Don't use space)
|
*/
// phpcs:enable
$config['reg_code'] = 'REG';
$config['unreg_code'] = 'UNREG';
