<?php

$finder = PhpCsFixer\Finder::create()
    //->notPath('file.php')
    ->notPath('libraries/abstract.plugins.php')
    ->exclude('libraries/b8/')
    ->notPath('libraries/Plugins_lib.php')
    ->notPath('libraries/Plugins_lib_kalkun.php')
    ->notPath('libraries/trait.plugins.php')
    ->exclude('plugins/rest_api/language/')
    ->exclude('plugins/rest_api/libraries/')
    ->notPath('plugins/rest_api/config/rest.php')
    ->exclude('plugins/sms_to_twitter/libraries/')
    ->exclude('plugins/sms_to_xmpp/libraries/abhinavsingh-JAXL-5829c3b/')
    ->exclude('plugins/soap/libraries/')
    ->exclude('tests/mocks/libraries/')
    ->exclude('third_party/')
    ->notPath('config/autoload.php')
    ->notPath('config/config.php')
    ->notPath('config/constants.php')
    ->notPath('config/database.php')
    ->notPath('config/doctypes.php')
    ->notPath('config/foreign_chars.php')
    ->notPath('config/hooks.php')
    //->notPath('config/kalkun_settings.php')
    ->notPath('config/memcached.php')
    ->notPath('config/migration.php')
    ->notPath('config/mimes.php')
    //->notPath('config/plugins.php')
    ->notPath('config/profiler.php')
    //->notPath('config/routes.php')
    ->notPath('config/smileys.php')
    ->notPath('config/user_agents.php')
    ->notPath('models/Plugins_model.php')
    ->notPath('helpers/plugin_helper.php')
    ->in('application')
    //->in(__DIR__)
;
