<?php
/**
 * System messages translation for CodeIgniter(tm)
 *
 * @author    CodeIgniter community
 * @author    Gabriel Potkány <gadelat+codeigniter@gmail.com>
 * @copyright Copyright (c) 2014-2019, British Columbia Institute of Technology (https://bcit.ca/)
 * @license   http://opensource.org/licenses/MIT MIT License
 * @link      https://codeigniter.com
 */
defined('BASEPATH') OR exit('No direct script access allowed');

$lang['date_year'] = 'Rok';
$lang['date_years'] = 'Roky';
$lang['date_month'] = 'Mesiac';
$lang['date_months'] = 'Mesiace';
$lang['date_week'] = 'Týždeň';
$lang['date_weeks'] = 'Týždne';
$lang['date_day'] = 'Deň';
$lang['date_days'] = 'Dni';
$lang['date_hour'] = 'Hodina';
$lang['date_hours'] = 'Hodiny';
$lang['date_minute'] = 'Minúta';
$lang['date_minutes'] = 'Minúty';
$lang['date_second'] = 'Sekunda';
$lang['date_seconds'] = 'Sekundy';

$lang['UM12'] = '(UTC -12:00) Bakerov/Howlandov ostrov';
$lang['UM11'] = '(UTC -11:00) Niue';
$lang['UM10'] = '(UTC -10:00) Hawajsko-Aleutianský Štandardný čas, Cookove ostrovy, Tahiti';
$lang['UM95'] = '(UTC -9:30) Markézy';
$lang['UM9'] = '(UTC -9:00) Aljašský Štandardní čas, Gambierovy ostrovy';
$lang['UM8'] = '(UTC -8:00) Pacifický Štandardný čas, Clippertonove ostrovy';
$lang['UM7'] = '(UTC -7:00) Horský Štandardný čas';
$lang['UM6'] = '(UTC -6:00) Centrálny Štandardný čas';
$lang['UM5'] = '(UTC -5:00) Východný Štandardný čas, Západný Karibský Štandardný čas';
$lang['UM45'] = '(UTC -4:30) Venezuelský Štandardný čas';
$lang['UM4'] = '(UTC -4:00) Atlantický Štandardný čas, Východný Karibský Štandardný čas';
$lang['UM35'] = '(UTC -3:30) Novofundlandský Štandardný čas';
$lang['UM3'] = '(UTC -3:00) Argentína, Brazília, Francúzska Guiana, Uruguay';
$lang['UM2'] = '(UTC -2:00) Južná Georgia a Južné Sandwichove ostrovy';
$lang['UM1'] = '(UTC -1:00) Azory, Ostrovy Cape Verde';
$lang['UTC'] = '(UTC) Greenwichský poludník, Západoeurópsky Čas';
$lang['UP1'] = '(UTC +1:00) Stredoeurópsky Čas, Západoafrický Čas';
$lang['UP2'] = '(UTC +2:00) Stredoafrický Čas, Východoeurópsky Čas, Kaliningradský Čas';
$lang['UP3'] = '(UTC +3:00) Moskva, Východoafrický Čas, Arabský Štandardný čas';
$lang['UP35'] = '(UTC +3:30) Íránsky Štandardný čas';
$lang['UP4'] = '(UTC +4:00) Azerbajdžanský Štandardný čas, Samarský čas';
$lang['UP45'] = '(UTC +4:30) Afganistan';
$lang['UP5'] = '(UTC +5:00) Pakistanský Štandardný čas, Yekaterinburgský Čas';
$lang['UP55'] = '(UTC +5:30) Indický Štandardný čas, Srí Lanka';
$lang['UP575'] = '(UTC +5:45) Nepál';
$lang['UP6'] = '(UTC +6:00) Bangladéšský Štandardný čas, Bhutan, Omsk';
$lang['UP65'] = '(UTC +6:30) Kokosové Ostrovy, Myanmar';
$lang['UP7'] = '(UTC +7:00) Krasnoyarský Čas, Kambodža, Laos, Thajsko, Vietnam';
$lang['UP8'] = '(UTC +8:00) Západoaustrálsky Štandardný čas, Pekingský Čas, Irkutsk';
$lang['UP875'] = '(UTC +8:45) Stredoaustrálsky Štandardný čas';
$lang['UP9'] = '(UTC +9:00) Japonský Štandardný čas, Kórejský Štandardný čas, Yakutský Čas';
$lang['UP95'] = '(UTC +9:30) Austrálsky Centrálny Štandardný čas';
$lang['UP10'] = '(UTC +10:00) Východoaustrálsky Štandardný čas, Vladivostok';
$lang['UP105'] = '(UTC +10:30) Ostrov lorda Howa';
$lang['UP11'] = '(UTC +11:00) Srednokolymský Čas, Solomonovy Ostrovy, Vanuatu';
$lang['UP115'] = '(UTC +11:30) Norfol (Ostrov)';
$lang['UP12'] = '(UTC +12:00) Fidži, Gilbertove Ostrovy, Kamčatský Čas, Novozélandský Štandardný čas';
$lang['UP1275'] = '(UTC +12:45) Chathamove ostrovy';
$lang['UP13'] = '(UTC +13:00) Samoa Časová Zóna, Fénixove Ostrovy, Tonga';
$lang['UP14'] = '(UTC +14:00) Liniové ostrovy';
