<?php

/*
 * Bulgarian language
 */

$lang['text_rest_invalid_api_key'] = 'Невалиден API ключ %s';
$lang['text_rest_invalid_credentials'] = 'Невалидни данни за достъп';
$lang['text_rest_ip_denied'] = 'Отказан IP адрес';
$lang['text_rest_ip_unauthorized'] = 'Неоторизиран IP адрес';
$lang['text_rest_unauthorized'] = 'Неоторизиран достъп';
$lang['text_rest_ajax_only'] = 'Само AJAX заявки са разрешени';
$lang['text_rest_api_key_unauthorized'] = 'API ключът не е оторизиран зо достъп до заявения контролер';
$lang['text_rest_api_key_permissions'] = 'API ключът няма достатъчно права';
$lang['text_rest_api_key_time_limit'] = 'API ключът е изполван с превишаване на времевия лимит за този метод';
$lang['text_rest_ip_address_time_limit'] = 'За текущия IP адрес е превишен времевия лимит за изпълнение на метода';
$lang['text_rest_unknown_method'] = 'Неизвестен метод';
$lang['text_rest_unsupported'] = 'Неподдържан протокол';
