<?php

$lang['Packages'] = 'Packages';
$lang['No package'] = 'Pas de package';
$lang['Package'] = 'Package';
$lang['Start date'] = 'Date de début';
$lang['End date'] = 'Date de fin';
$lang['Are you sure you want to delete this user?'] = 'Êtes-vous sûr⋅e de vouloir supprimer cet utilisateur ?';
$lang['Add packages'] = 'Ajouter despackages';
$lang['Edit packages'] = 'Editer des packages';
$lang['Edit user package'] = 'Editer le package de l\\\'utilisateur';
$lang['Add Packages'] = 'Ajouter des Packages';
$lang['Package name'] = 'Nom du package';
$lang['SMS Amount'] = 'Quantité de SMS';
$lang['Delete Packages Confirmation'] = 'Confirmation de suppression des packages';
$lang['Are you sure to delete this package? All users belonging to this package will no longer be limited.'] = 'Êtes-vous sûr⋅e de vouloir supprimer ce package ? Tous les utilisateurs utilisant ce package ne seront plus limités.';
$lang['Sorry, your sms credit limit exceeded.'] = 'sssSorry, your sms credit limit exceeded.';
