<?php
defined('BASEPATH') OR exit('No direct script access allowed');

// phpcs:disable CodeIgniter.Commenting.InlineComment.WrongStyle
/*
|--------------------------------------------------------------------------
| CONFIGURATION
|--------------------------------------------------------------------------
|
| url - url location to lookup the phone number, the phone number variable should be #phonenumber#
|
*/
// phpcs:enable
$config['url'] = 'http://www.krak.dk/person/resultat/#phonenumber#';
