<?php
defined('BASEPATH') OR exit('No direct script access allowed');

// phpcs:disable CodeIgniter.Commenting.InlineComment.WrongStyle
/*
|--------------------------------------------------------------------------
| CONFIGURATION
|--------------------------------------------------------------------------
|
| twitter_code - Twitter code (Don't use space)
|
*/
// phpcs:enable
$config['twitter_code'] = 'TW';

// Fill with your OAuth credentials
$config['consumer_key'] = '';
$config['consumer_key_secret'] = '';
