<?php

/*
 * Serbian language
 */

$lang['text_rest_invalid_api_key'] = 'Неправилан *API* кључ %s'; // %s је *REST API* кључ
$lang['text_rest_invalid_credentials'] = 'Неодговарајући кориснички улазни подаци';
$lang['text_rest_ip_denied'] = '*IP* одбијен';
$lang['text_rest_ip_unauthorized'] = '*IP* неауторизован';
$lang['text_rest_unauthorized'] = 'Неауторизовано';
$lang['text_rest_ajax_only'] = 'Једино *AJAX* захтеви су дозвољени';
$lang['text_rest_api_key_unauthorized'] = 'Овај *API* кључ нема овлашћења за захтевани контролер';
$lang['text_rest_api_key_permissions'] = 'Овај *API* кључ нема дозвољен степен овлашћења';
$lang['text_rest_api_key_time_limit'] = 'Овај *API* кључ је прекорачио временски лимит за дати метод';
$lang['text_rest_ip_address_time_limit'] = 'Ова *IP* адреса је прекорачила временски лимит за дати метод'; //todo translate
$lang['text_rest_unknown_method'] = 'Непознат метод';
$lang['text_rest_unsupported'] = 'Неподржан протокол';
