<!-- Values are filled in javascript -->
<?php echo tr('Status'); ?>:
<span id="modem_connection_status"><?php echo tr('Unknown'); ?></span>
| <?php echo tr('Signal'); ?>:
<span id="modem_connection_signal"><?php echo tr('Unknown'); ?></span>
| <?php echo tr('Battery'); ?>:
<span id="modem_connection_battery"><?php echo tr('Unknown'); ?></span>
