<?php

/*
 * Simple Chinese language
 */

$lang['text_rest_invalid_api_key'] = '无效的 API key %s'; // %s is the REST API key
$lang['text_rest_invalid_credentials'] = '无效的凭证';
$lang['text_rest_ip_denied'] = 'IP 地址被拒绝';
$lang['text_rest_ip_unauthorized'] = 'IP 地址未认证';
$lang['text_rest_unauthorized'] = '未认证';
$lang['text_rest_ajax_only'] = '只允许 AJAX 类型的请求';
$lang['text_rest_api_key_unauthorized'] = '此 API key无法存取指定的 controller';
$lang['text_rest_api_key_permissions'] = '此 API key没有足够的权限';
$lang['text_rest_api_key_time_limit'] = '此 API key已经超过有效期限';
$lang['text_rest_ip_address_time_limit'] = 'This IP Address has reached the time limit for this method'; //todo translate
$lang['text_rest_unknown_method'] = '未知的方法';
$lang['text_rest_unsupported'] = '不支持的请求方法';
