<?php

$lang['Packages'] = 'Packages';
$lang['No package'] = 'No package';
$lang['Package'] = 'Package';
$lang['Start date'] = 'Start date';
$lang['End date'] = 'End date';
$lang['Are you sure you want to delete this user?'] = 'Are you sure you want to delete this user?';
$lang['Add packages'] = 'Add packages';
$lang['Edit packages'] = 'Edit packages';
$lang['Edit user package'] = 'Edit user package';
$lang['Add Packages'] = 'Add Packages';
$lang['Package name'] = 'Package name';
$lang['SMS Amount'] = 'SMS Amount';
$lang['Delete Packages Confirmation'] = 'Delete Packages Confirmation';
$lang['Are you sure to delete this package? All users belonging to this package will no longer be limited.'] = 'Are you sure to delete this package? All users belonging to this package will no longer be limited.';
$lang['Sorry, your sms credit limit exceeded.'] = 'Sorry, your sms credit limit exceeded.';
