<div class="two_column_container toolbar">
	<div class="left_column">

	</div>
	<div class="right_column">
		<div id="simplepaging" class="paging_grey"><?php echo $pagination_links;?></div>
	</div>
</div>
