<?php
// German Translation
// Author: Thomas Freislich <thomas.freislich@gmail.com>

// Global
$lang['Dashboard'] = 'Übersicht';
$lang['Folders'] = 'Ordner';
$lang['My folders'] = 'Meine Ordner';

$lang['Compose'] = 'Verfassen';
$lang['Inbox'] = 'Eingang';
$lang['Outbox'] = 'Ausgang';
$lang['Sent items'] = 'Gesendet';
$lang['Sending error'] = 'Sending Error';
$lang['Trash'] = 'Papierkorb';
$lang['Spam'] = 'Spam';
$lang['Add'] = 'Neu';
$lang['Action'] = 'Aktion';

$lang['Phonebook'] = 'Adressbuch';
$lang['Settings'] = 'Einstellungen';
$lang['Filters'] = 'Filters';
$lang['About {0}'] = 'About {0}';
$lang['Logout'] = 'Abmelden';

// Dashboard
$lang['Statistics'] = 'Statistik';
$lang['System information'] = 'System Information';
$lang['Alerts'] = 'Alarm';
$lang['Operating system'] = 'Betriebssystem';
$lang['Gammu version'] = 'Gammu Version';
$lang['Gammu DB schema'] = 'Gammu DB Schema';
$lang['Modem IMEI'] = 'Modem IMEI';

// Phonebook
$lang['Contact'] = 'Kontakte';
$lang['All contacts'] = 'All Contacts';
$lang['Send to all contacts'] = 'Send To All Contacts';
$lang['Add to group'] = 'Zu Gruppe hinzufügen';
$lang['Delete from group'] = 'Von Gruppe löschen';
$lang['Select add contact method'] = 'Methode zum hinzufügen von Kontakten wählen';
$lang['Manual input'] = 'Kontaktformular benutzen';
$lang['Manually add contact using contact form'] = 'Kontakt händische mithilfe des Kontaktformulars hinzufügen';
$lang['From CSV file'] = 'CSV-Datei importieren';
$lang['Import contact from CSV format file'] = 'Kontakt aus CSV-Datei importieren';
$lang['CSV file'] = 'CSV Datei';
$lang['The CSV file must be in valid format'] = 'Die CSV-Datei muss in einem gültigen Format vorliegen';
$lang['Are you sure you want to delete {0} contact(s)?'] = 'Sind Sie sicher, dass sie {0} Kontakt(e) löschen wollen?';
$lang['valid example'] = 'Beispiel';

// Message
$lang['Message'] = 'Nachricht';
$lang['Send to'] = 'Senden an';
$lang['Reply'] = 'Antworten';
$lang['Forward'] = 'Weiterleiten';
$lang['Forward to'] = 'Weiterleiten an';
$lang['Move to'] = 'Verschieben nach';
$lang['Select folder'] = 'Ordner auswählen';
$lang['Delete'] = 'Löschen';
$lang['Click to delete this folder'] = 'Hier klicken um diesen Ordner zu löschen';
$lang['Recover'] = 'Wiederherstellen';

$lang['Send date'] = 'Sendedatum';
$lang['Now'] = 'Jetzt';
$lang['At date and time'] = 'Zu bestimmter Uhrzeit';
$lang['After a delay'] = 'Nach einer Verzögerung';

$lang['Input manually'] = 'Telefonnummer(n) händisch eingeben';

$lang['Add folder'] = 'Ordner hinzufügen';
$lang['Folder name'] = 'Ordnername';
$lang['Cancel'] = 'Abbrechen';
$lang['Save'] = 'Speichern';
$lang['Rename'] = 'Umbennenen';
$lang['Rename folder'] = 'Ordner umbennenen';
$lang['Click to rename this folder'] = 'Hier klicken um diesen Ordner umzubennenen';

$lang['This folder and all messages in it will be deleted permanently and cannot be recovered. Are you sure?'] = 'Dieser Ornder und alle Nachrichten darin werden dauerhaft gelöscht. Sind Sie sich sicher?';

$lang['There is no message in {0}.'] = 'Es sind keine Nachrichten in Ihrem {0}.';
$lang['There is no message in this folder.'] = 'Es sind keine Nachrichten in diesem Ordner.';

$lang['Delete all'] = 'Alle löschen';
$lang['Are you sure? This will affect all conversations.'] = 'Sind Sie sich sicher? Dies betrifft alle Konversationen.';

$lang['Select all'] = 'Alle';
$lang['Deselect all'] = 'Keine';
$lang['Refresh'] = 'Aktualisieren';

$lang['Report spam'] = 'Als Spam kennzeichnen';
$lang['Not spam'] = 'Kein Spam';


$lang['SMSC'] = 'SMSC';
$lang['Part'] = 'Teil';
$lang['Validity'] = 'Gültigkeit';
$lang['default'] = 'default';
$lang['5 minutes'] = '5 minutes';
$lang['10 minutes'] = '10 minutes';
$lang['30 minutes'] = '30 minutes';
$lang['1 hour'] = '1 hour';
$lang['2 hours'] = '2 hours';
$lang['4 hours'] = '4 hours';
$lang['12 hours'] = '12 hours';
$lang['1 day'] = '1 day';
$lang['2 days'] = '2 days';
$lang['5 days'] = '5 days';
$lang['1 week'] = '1 week';
$lang['2 weeks'] = '2 weeks';
$lang['4 weeks'] = '4 weeks';
$lang['maximum'] = 'maximum';

$lang['SMS type'] = 'SMS Typ';
$lang['Normal'] = 'Normal';
$lang['Flash'] = 'Flash';
$lang['WAP push link'] = 'WAP Push Link';
$lang['URL'] = 'URL';

$lang['Ads is active'] = 'Werbung ist aktiv';
$lang['Check DND'] = 'DND überprüfen';
$lang['Insert'] = 'Einfügen';

$lang['Canned responses'] = 'Vorlagen';
$lang['There are no canned responses. Continue to save your present message as canned response.'] = 'Es sind keine Vorlagen vorhanden. Zuerst Vorlage speichern.';
$lang['Choose response'] = 'Antworten auswöhlen';
$lang['Saving...'] = 'Speichern...';
$lang['Are you sure?'] = 'Sind Sie sich sicher?';

// Others
$lang['Amount'] = 'Menge';
$lang['times']['repetition'] = 'mal';
$lang['Hour(s)'] = 'Stunden';
$lang['Minutes'] = 'Minuten';
$lang['No result.'] = 'Oops! Es wurden keine Einträge gefunden.';
$lang['See conversation'] = 'Konversation anschauen';

$lang['Search'] = 'Suchen';
$lang['Advanced search'] = 'Erweiterte Suche';
$lang['Folder'] = 'Suchen in';
$lang['All'] = 'Alle Ordner';
$lang['Date from'] = 'Datum von';
$lang['Date to'] = 'Datum bist';
$lang['Status'] = 'Status';
$lang['Paging'] = 'Seiten';
$lang['{0} per page'] = '{0} pro Seite';

$lang['Resend'] = 'Erneut Senden';
$lang['Public contacts'] = 'Öffentl. Kontakte';
$lang['Set as public contact'] = 'Als öffentl. Kontakt setzen';
$lang['My contacts'] = 'Meine Kontakte';
$lang['Public groups'] = 'Öffentl. Gruppen';
$lang['Set as public group'] = 'Als öffentl. Gruppe setzen';
$lang['My groups'] = 'Meine Gruppen';
$lang['Incoming SMS'] = 'Empfangene SMS';
$lang['Outgoing SMS'] = 'Gesendete SMS';
$lang['Delete all messages now'] = 'Alle Nachrichten löschen';
$lang['Delete contact(s) confirmation'] = 'Kontakt(e) löschen Bestätigung';
$lang['Should be a valid URL'] = 'Muss eine gültige URL sein';
$lang['Import from file'] = 'Von Datei importieren';

// Messages controller
$lang['Outgoing SMS disabled.'] = 'Outgoing SMS disabled.';
$lang['A number was found in DND Resitry. SMS sending was skipped for it.'] = 'A number was found in DND Resitry. SMS sending was skipped for it.';
$lang['Message delivered successfully to user inbox.'] = 'Message successfully delivered to user inbox.';
$lang['Copy of the message was placed in the outbox and is ready for delivery.'] = 'Your message has been moved to outbox and is ready for delivery.';
$lang['No number found. SMS not sent.'] = 'No number found. SMS not sent.';
$lang['Only administrators can permanently delete messages.'] = 'Only administrators can permanently delete messages.';

// Setting
$lang['Current password'] = 'Aktuelles Passwort';
$lang['Forgot your password?'] = 'Passswort vergessen?';
$lang['New password'] = 'Neues Passwort';
$lang['Must be at least 6 characters long'] = 'Muss mindestens 6 Zeichen lang sein';

$lang['Enter your new password'] = 'Neues Passwort eingeben';

$lang['Administrator'] = 'Administrator';
$lang['User']['credentials'] = 'Benutzer';

$lang['Create a new filter'] = 'Create a new filter';
$lang['Has the words'] = 'Has the words';

// SMS Content/Member
$lang['Member'] = 'Mitglied';
$lang['Total member'] = 'Mitglieder total';
$lang['There is no registered member yet'] = 'Es ist keine registriertes Mitglied vorhanden';

// tni contribution
$lang['Add contact'] = 'Kontakt hinzufügen';
$lang['Send message'] = 'Nachricht senden';
$lang['Send and repeat'] = 'Send and Repeat';
$lang['Sending'] = 'Senden';
$lang['Insert name from contact list'] = 'Name von Addressbuch einfügen';
$lang['Delete group(s) confirmation'] = 'Gruppe(n) löschen Bestätigung';
$lang['Delete group(s)?
All their contacts will also be deleted.'] = 'Gruppe(n) löschen?
Alle Kontakte in dieser Gruppe(n) werden auch gelöscht!.';
$lang['Create group'] = 'Gruppe erstellen';
$lang['Group name'] = 'Gruppen Name';
$lang['Groups'] = 'Gruppen';
$lang['Manage groups'] = 'Gruppen verwalten';
$lang['Manage group'] = 'Gruppe verwalten';
$lang['Manage contact'] = 'Kontakt verwalten';
$lang['Type group name'] = 'Gruppe auswählen';
$lang['No item selected.'] = 'Kein Element ausgewählt.';
$lang['No contact selected.'] = 'Kein Kontakt ausgewählt.';
$lang['Compose SMS'] = 'SMS verfassen';
$lang['Contacts'] = 'Kontakte';
$lang['Back to {0}'] = 'Zurück zu {0}';
$lang['Show details'] = 'Details anzeigen';
$lang['Hide details'] = 'Details verstekcen';
$lang['Search contacts'] = 'Kontakte durchsuchen';
$lang['Search messages'] = 'Nachrichten durchsuchen';
$lang['Edit'] = 'Bearbeiten';
$lang['All form fields are required.'] = 'Alle Felder müssen ausgefüllt werden.';
$lang['Name'] = 'Name';
$lang['Telephone number'] = 'Telefonnummer';
$lang['Email ID'] = 'Email ID';
$lang['Enable email forwarding'] = 'Email Weiterleitung aktivieren';
$lang['{0} remaining'] = '{0} remaining';
$lang['{0} ago'] = '{0} ago';
$lang['Edit contact'] = 'Kontakt bearbeiten';
$lang['Contact not found'] = 'Benutzer nicht gefunden';
$lang['No contacts in the database.'] = 'Keine Einträge';
$lang['Add user'] = 'Benutzer hinzufügen';
$lang['Edit user'] = 'Benutzer bearbeiten';
$lang['User']['default'] = 'Benutzer';
$lang['Users'] = 'Benutzer';
$lang['This deletes the selected users and all their messages and contacts.'] = 'Benutzer löschen?
Es werden alle Nachrichten und Kontakte von diesem Benutzer gelöscht.';
$lang['User not found'] = 'Benutzer nicht gefunden';
$lang['No users in the database.'] = 'Benutzer ist leer';
$lang['Username'] = 'Benutzername';
$lang['Password'] = 'Passwort';
$lang['Search user'] = 'Suchen';
$lang['Confirm password'] = 'Passwort bestätigen';
$lang['Phone number'] = 'Telefonnummer';
$lang['Action not allowed'] = 'Aktivität nicht erlaubt';
$lang['Field required.'] = 'Field required.';
$lang['Passwords do not match.'] = 'Passwörter stimmen nicht überein.';
$lang['No user selected'] = 'Kein Benutzer ausgewählt';
$lang['Delete this folder'] = 'Diesen Ordner löschen';
$lang['Loading'] = 'Laden';
$lang['Connected'] = 'Verbunden';
$lang['Disconnected'] = 'Nicht verbunden';
$lang['No group detected, add one first.'] = 'Keine Gruppe gefunden. Bitte zuerst eine Gruppe hinzufügen.';
$lang['No group selected.'] = 'Keine Gruppe ausgewählt.';
$lang['From'] = 'Von';
$lang['To'] = 'An';
$lang['Inserted'] = 'Eingefügt';
$lang['Date'] = 'Datum';
$lang['Sending failed'] = 'Senden fehlgeschlagen';
$lang['Sent, no report'] = 'Sending OK';
$lang['Sent, waiting for report'] = 'Sending OK - Auf Bestätigung warten';
$lang['Delivered'] = 'Ausgeliefert';
$lang['Pending'] = 'Unerledigt';
$lang['Unknown'] = 'Unbekannt';

$lang['Country calling code'] = 'Country calling code';

$lang['Conversation sort'] = 'Konversation sortieren';

$lang['Data per page'] = 'Daten pro Seiten';
$lang['Used for paging in message and phonebook'] = 'Wir für die Anzeige von Nachrichten und Adressbuch benutzt';

$lang['Permanent delete'] = 'Dauerhaft löschen';
$lang['Disable'] = 'Aus';
$lang['Always move to trash first'] = 'Zuerst immer in den Papierkorb verschieben';
$lang['Enable'] = 'An';

$lang['User settings'] = 'Benutzer Einstellungen';
$lang['General'] = 'Allgemein';
$lang['Personal'] = 'Privat';

$lang['Signature'] = 'Signatur';
$lang['Max. 50 characters'] = 'Max. 50 Zeichen';
$lang['Signature is added at the end of the message.'] = 'Signatur wird am Ende jeder Nachricht angefügt.';
$lang['Language'] = 'Sprache';
$lang['Yes'] = 'Ja';
$lang['No'] = 'Nein';
$lang['Default'] = 'Standard';
$lang['Delivery Report'] = 'Sendebestätigung';

$lang['Delete copy (prevents duplicates).'] = 'Delete copy of this message (Prevent Duplicate).';
$lang['You are about to resend {0} message(s).'] = 'You are about to resend {0} message(s).';

// Kalkun Controller
$lang['Outgoing SMS disabled. Contact system administrator.'] = 'Outgoing SMS Disabled. Contact System Administrator.';
$lang['Wrong password'] = 'You entered wrong password';
$lang['Username already taken'] = 'Username already exists';
$lang['Settings saved successfully.'] = 'Your settings have been saved.';
// Users Controller
$lang['Access denied.'] = 'Access denied.';
$lang['User updated successfully.'] = 'User has been updated.';
$lang['User added successfully.'] = 'User has been added.';
// Pluginss Controller
$lang['Access denied. Only administrators are allowed to manage plugins.'] = 'Only administrators can manage plugins.';
$lang['Plugin {0} installed successfully.'] = 'Plugin {0} successfully installed.';
$lang['Plugin {0} uninstalled successfully.'] = 'Plugin {0} successfully uninstalled.';
$lang['Installed']['Plural'] = 'Installed';
$lang['Available']['Plural'] = 'Available';
// Phonebook Controller
$lang['{0,number,integer} contacts imported successfully.'] = '{0,number,integer} contacts successfully imported.';
$lang['Contact updated successfully.'] = 'Contact has been updated.';
$lang['Contact added successfully.'] = 'Contact has been added.';
// Gammu Model
$lang['Message queued.'] = 'Message queued.';
$lang['Parameter invalid.'] = 'Parameter invalid.';

$lang['403 Forbidden'] = '403 Forbidden';

$lang['Close'] = 'Close';
$lang['Previous'] = 'Previous';
$lang['Next'] = 'Next';
$lang['Continue'] = 'Continue';
$lang['Submit']['form'] = 'Submit';
$lang['Log in'] = 'Log in';
$lang['Username or password are incorrect.'] = 'Username or password are incorrect.';
$lang['Token already generated and still active.'] = 'Token already generated and still active.';
$lang['To reset your Kalkun password please visit {0}'] = 'To reset your Kalkun password please visit {0}';
$lang['If you are a registered user, a SMS has been sent to you.'] = 'If you are a registered user, a SMS has been sent to you.';
$lang['Password changed successfully.'] = 'Password changed successfully.';
$lang['Token invalid.'] = 'Token invalid.';
$lang['Password reset'] = 'Password reset';
$lang['or'] = 'or';
$lang['Please enter your username and password'] = 'Please enter your username and password';
$lang['Remember me'] = 'Remember me';
$lang['Installation'] = 'Installation';
$lang['Installation steps'] = 'Installation steps';
$lang['Welcome screen'] = 'Welcome screen';
$lang['Requirements check'] = 'Requirements check';
$lang['Database setup'] = 'Database setup';
$lang['Final configuration steps'] = 'Final configuration steps';
$lang['Ok'] = 'Ok';
$lang['Missing'] = 'Missing';
$lang['Found'] = 'Found';
$lang['Successful'] = 'Successful';
$lang['Failed'] = 'Failed';
$lang['Kalkun installation assistant'] = 'Kalkun installation assistant';
$lang['This welcome screen'] = 'This welcome screen';
$lang['Database installation or upgrade'] = 'Database installation or upgrade';
$lang['Keyboard shortcuts'] = 'Keyboard shortcuts';
$lang['Jumping'] = 'Jumping';
$lang['{0} then {1}:'] = '{0} then {1}:';
$lang['Navigation'] = 'Navigation';
$lang['Back to conversation list'] = 'Back to conversation list';
$lang['Highlight prev/next'] = 'Highlight prev/next';
$lang['Open prev/next (message only)'] = 'Open prev/next (message only)';
$lang['{0} or {1}:'] = '{0} or {1}:';
$lang['Open'] = 'Open';
$lang['Selection'] = 'Selection';
$lang['Select'] = 'Select';
$lang['Actions'] = 'Actions';
$lang['Move selected'] = 'Move selected';
$lang['Delete selected'] = 'Delete selected';
$lang['Message details'] = 'Message details';
$lang['Application'] = 'Application';
$lang['Open shortcut help'] = 'Open shortcut help';
$lang['Error'] = 'Error';
$lang['Please specify a valid mobile phone number'] = 'Please specify a valid mobile phone number';
$lang['Go to {0}'] = 'Go to {0}';
$lang['Please enter a name for your message. It should be unique.'] = 'Please enter a name for your message. It should be unique.';
$lang['Are you sure? This will overwrite the previous message.'] = 'Are you sure? This will overwrite the previous message.';
$lang['PHP Frontend for gammu-smsd'] = 'PHP Frontend for gammu-smsd';
$lang['Authors'] = 'Authors';
$lang['See {0} page'] = 'See {0} page';
$lang['Version'] = 'Version';
$lang['Released'] = 'Released';
$lang['License'] = 'License';
$lang['Homepage'] = 'Homepage';
$lang['Add a new folder'] = 'Add a new folder';
$lang['Plugins'] = 'Plugins';
$lang['No data'] = 'No data';
$lang['Select field'] = 'Select field';
$lang['Delete folder'] = 'Delete folder';
$lang['Role'] = 'Role';
$lang['Delete users'] = 'Delete users';
$lang['Theme'] = 'Theme';
$lang['Background image'] = 'Background image';
$lang['Ascending'] = 'Ascending';
$lang['Descending'] = 'Descending';
$lang['Value is too short.'] = 'Value is too short.';
$lang['Select group name'] = 'Select group name';
$lang['Uninstall'] = 'Uninstall';
$lang['Install'] = 'Install';
$lang['Author'] = 'Author';
$lang['No plugin available.'] = 'No plugin available.';
$lang['No plugin installed.'] = 'No plugin installed.';
$lang['Retrying now'] = 'Retrying now';
$lang['{0} character(s) / {1} message(s)'] = '{0} character(s) / {1} message(s)';
$lang['{0} message(s) deleted'] = '{0} message(s) deleted';
$lang['{0} conversation(s) recovered'] = '{0} conversation(s) recovered';
$lang['Messages moved successfully'] = 'Messages moved successfully';
$lang['Outgoing message cannot be spam'] = 'Outgoing message cannot be spam';
$lang['Spam reported'] = 'Spam reported';
$lang['Message(s) marked non-spam'] = 'Message(s) marked non-spam';
$lang['{0} conversation(s) deleted'] = '{0} conversation(s) deleted';
$lang['{0} conversation(s) moved'] = '{0} conversation(s) moved';
$lang['Value is too long.'] = 'Value is too long.';
$lang['Updated'] = 'Updated';
$lang['Import'] = 'Import';
$lang['Reset search'] = 'Reset search';
$lang['No.']['Number abbreviation'] = 'No.';
$lang['Insertion date'] = 'Insertion date';
$lang['Control'] = 'Control';
$lang['Plugin {0} is not installed.'] = 'Plugin {0} is not installed.';
$lang['Value must be a number.'] = 'Value must be a number.';
$lang['{0} part messages'] = '{0} part messages';
$lang['Content'] = 'Content';
$lang['No results for {0}'] = 'No results for {0}';
$lang['Failure to inject message into Gammu with gammu-smsd-inject. See kalkun logs.'] = 'Failure to inject message into Gammu with gammu-smsd-inject. See kalkun logs.';
$lang['Group'] = 'Group';
$lang['Delete the original message (prevents duplicates).'] = 'Delete the original message (prevents duplicates).';
$lang['Delete permanently'] = 'Delete permanently';
$lang['Retrying in {0} seconds.'] = 'Retrying in {0} seconds.';
$lang['Signal'] = 'Signal';
$lang['Battery'] = 'Battery';
$lang['Writable'] = 'Writable';
$lang['Read-only'] = 'Read-only';
$lang['Inbox Master'] = 'Inbox Master';
$lang['Network error.'] = 'Network error.';
$lang['{0}%'] = '{0}%';
$lang['Item deleted.'] = 'Item deleted.';
$lang['Installation has been disabled by the administrator.
To enable access to it, create a file named {0} in this directory of the server: {1}.
Otherwise you may log-in at {2}.'] = 'Installation has been disabled by the administrator.
To enable access to it, create a file named {0} in this directory of the server: {1}.
Otherwise you may log-in at {2}.';
$lang['There is no message in this conversation.'] = 'There is no message in this conversation.';
$lang['Check again'] = 'Check again';
$lang['Password modification forbidden in demo mode.'] = 'Password modification forbidden in demo mode.';
$lang['Settings saved successfully (except username for kalkun user which can\'t be changed in demo mode)'] = 'Settings saved successfully (except username for kalkun user which can\'t be changed in demo mode)';
$lang['Modification of username of "kalkun" user forbidden in demo mode. Username was restored.'] = 'Modification of username of "kalkun" user forbidden in demo mode. Username was restored.';
$lang['Process incoming messages'] = 'Process incoming messages';
$lang['Changing role of "kalkun" user forbidden in demo mode. Role was restored.'] = 'Changing role of "kalkun" user forbidden in demo mode. Role was restored.';
