<?php
/**
 * System messages translation for CodeIgniter(tm)
 *
 * @author	CodeIgniter community
 * @copyright	Copyright (c) 2014-2019, British Columbia Institute of Technology (https://bcit.ca/)
 * @license	http://opensource.org/licenses/MIT	MIT License
 * @link	https://codeigniter.com
 */
defined('BASEPATH') OR exit('Nenhum acesso direto ao script é permitido');

$lang['date_year'] = 'Ano';
$lang['date_years'] = 'Anos';
$lang['date_month'] = 'Mês';
$lang['date_months'] = 'Meses';
$lang['date_week'] = 'Semana';
$lang['date_weeks'] = 'Semanas';
$lang['date_day'] = 'Dia';
$lang['date_days'] = 'Dias';
$lang['date_hour'] = 'Hora';
$lang['date_hours'] = 'Horas';
$lang['date_minute'] = 'Minuto';
$lang['date_minutes'] = 'Minutos';
$lang['date_second'] = 'Segundo';
$lang['date_seconds'] = 'Segundos';

$lang['UM12'] = '(UTC -12:00) Ilhas Baker e Howland';
$lang['UM11'] = '(UTC -11:00) Fuso horário de Samoa, Niue';
$lang['UM10'] = '(UTC -10:00) Horário padrão do Havaí e Aleutas, Ilhas Cook, Taiti';
$lang['UM95'] = '(UTC -9:30) Ilhas Marquesas';
$lang['UM9'] = '(UTC -9:00) Horário padrão do Alaska, Ilhas Gambier';
$lang['UM8'] = '(UTC -8:00) Horário padrão do Pacífico, Ilha Clipperton';
$lang['UM7'] = '(UTC -7:00) Horário padrão de Mountain';
$lang['UM6'] = '(UTC -6:00) Horário da cidade do México';
$lang['UM5'] = '(UTC -5:00) Horário padrão oriental, Horário padrão do Caribe Ocidental';
$lang['UM45'] = '(UTC -4:30) Horário padrão da Venezuela';
$lang['UM4'] = '(UTC -4:00) Horário padrão do Atlântico, Horário padrão do Caribe Oriental';
$lang['UM35'] = '(UTC -3:30) Horário padrão de Terra Nova';
$lang['UM3'] = '(UTC -3:00) Argentina, Brasil, Guiana Francesa, Uruguai';
$lang['UM2'] = '(UTC -2:00) Geórgia do Sul/Ilhas Sandwich do Sul';
$lang['UM1'] = '(UTC -1:00) Açores, Ilhas de Cabo Verde';
$lang['UTC'] = '(UTC) Horário padrão de Greenwich, Horário da Europa ocidental';
$lang['UP1'] = '(UTC +1:00) Horário da Europa Central, Horário do oeste africano';
$lang['UP2'] = '(UTC +2:00) Horário da Africa Central, Horário da Europa Oriental, Horário de Kaliningrado';
$lang['UP3'] = '(UTC +3:00) Horário de Moscou, Horário do leste da Africa';
$lang['UP35'] = '(UTC +3:30) Horário padrão do Irã';
$lang['UP4'] = '(UTC +4:00) Horário padrão do Azerbaijão, Horário de Samara';
$lang['UP45'] = '(UTC +4:30) Afeganistão';
$lang['UP5'] = '(UTC +5:00) Horário padrão do Paquistão, Horário de Ecaterimburgo';
$lang['UP55'] = '(UTC +5:30) Horário padrão da Índia, Horário de Sri Lanka';
$lang['UP575'] = '(UTC +5:45) Horário do Nepal';
$lang['UP6'] = '(UTC +6:00) Horário padrão de Bangladesh, Horário de Butão, Horário de Omsk';
$lang['UP65'] = '(UTC +6:30) Ilhas Cocos, Myanmar';
$lang['UP7'] = '(UTC +7:00) Horário de Krasnoyarsk, Cambodja, Laos, Tailândia, Vietnã';
$lang['UP8'] = '(UTC +8:00) Horário Padrão da Austrália Ocidental, Horário de Beijing, Horário de Irkutsk';
$lang['UP875'] = '(UTC +8:45) Horário Padrão Ocidental da Austrália Central';
$lang['UP9'] = '(UTC +9:00) Horário padrão do Japão, Horário padrão da Coreia, Horário de Yakutsk';
$lang['UP95'] = '(UTC +9:30) Horário padrão da Austrália Central';
$lang['UP10'] = '(UTC +10:00) Horário padrão da Austrália Oriental, Horário de Vladivostok';
$lang['UP105'] = '(UTC +10:30) Ilha de Lord Howe';
$lang['UP11'] = '(UTC +11:00) Horário de Magadan, Ilhas Salomão, Vanuatu';
$lang['UP115'] = '(UTC +11:30) Ilha Norfolk';
$lang['UP12'] = '(UTC +12:00) Fiji, Ilhas Gilbert, Horário de Kamchatka, Horário padrão da Nova Zelândia';
$lang['UP1275'] = '(UTC +12:45) Horário padrão das ilhas Chatham';
$lang['UP13'] = '(UTC +13:00) Horário das ilhas Fênix, Tonga';
$lang['UP14'] = '(UTC +14:00) Ilhas Line';
