<?php

/*
 * German language
 */

$lang['text_rest_invalid_api_key'] = 'Ungültiger API Schlüssel %s'; // %s is the REST API key | %s ist der REST API Schlüssel
$lang['text_rest_invalid_credentials'] = 'Ungültige Zugangsdaten';
$lang['text_rest_ip_denied'] = 'IP abgelehnt';
$lang['text_rest_ip_unauthorized'] = 'IP nicht autorisiert';
$lang['text_rest_unauthorized'] = 'Nicht autorisiert';
$lang['text_rest_ajax_only'] = 'Nur AJAX-Anfragen zulässig';
$lang['text_rest_api_key_unauthorized'] = 'Dieser API Schlüssel hat keinen Zugriff auf den angeforderten Controller';
$lang['text_rest_api_key_permissions'] = 'Dieser API Schlüssel besitzt die erforderlichen Rechte nicht';
$lang['text_rest_api_key_time_limit'] = 'Dieser API Schlüssel ist abgelaufen';
$lang['text_rest_ip_address_time_limit'] = 'This IP Address has reached the time limit for this method'; //todo translate
$lang['text_rest_unknown_method'] = 'Unbekannte Methode';
$lang['text_rest_unsupported'] = 'Protokoll nicht unterstützt';
